# -*- coding: utf-8 -*-
#
# Copyright (c) 2012-2014, CRS4
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

SEGMENTS = {'ABS': ('sequence',
         (('ABS_1', (0, 1)),
          ('ABS_2', (0, 1)),
          ('ABS_3', (0, 1)),
          ('ABS_4', (0, 1)),
          ('ABS_5', (0, 1)),
          ('ABS_6', (0, 1)),
          ('ABS_7', (0, 1)),
          ('ABS_8', (0, 1)),
          ('ABS_9', (0, 1)),
          ('ABS_10', (0, 1)),
          ('ABS_11', (0, 1)),
          ('ABS_12', (0, 1)),
          ('ABS_13', (0, 1)),
          ('ABS_14', (0, 1)))),
 'ACC': ('sequence',
         (('ACC_1', (0, 1)),
          ('ACC_2', (0, 1)),
          ('ACC_3', (0, 1)),
          ('ACC_4', (0, 1)),
          ('ACC_5', (0, 1)),
          ('ACC_6', (0, 1)),
          ('ACC_7', (0, 1)),
          ('ACC_8', (0, 1)),
          ('ACC_9', (0, 1)),
          ('ACC_10', (0, 1)),
          ('ACC_11', (0, 1)))),
 'ADD': ('sequence', (('ADD_1', (0, 1)),)),
 'ADJ': ('sequence',
         (('ADJ_1', (1, 1)),
          ('ADJ_2', (1, 1)),
          ('ADJ_3', (1, 1)),
          ('ADJ_4', (1, 1)),
          ('ADJ_5', (0, 1)),
          ('ADJ_6', (0, 1)),
          ('ADJ_7', (0, -1)),
          ('ADJ_8', (0, 1)),
          ('ADJ_9', (0, 1)),
          ('ADJ_10', (0, 1)),
          ('ADJ_11', (0, 1)),
          ('ADJ_12', (0, 1)),
          ('ADJ_13', (0, 1)),
          ('ADJ_14', (1, 1)),
          ('ADJ_15', (0, 1)))),
 'AFF': ('sequence',
         (('AFF_1', (1, 1)),
          ('AFF_2', (1, 1)),
          ('AFF_3', (0, 1)),
          ('AFF_4', (0, -1)),
          ('AFF_5', (0, 1)))),
 'AIG': ('sequence',
         (('AIG_1', (1, 1)),
          ('AIG_2', (0, 1)),
          ('AIG_3', (0, 1)),
          ('AIG_4', (1, 1)),
          ('AIG_5', (0, -1)),
          ('AIG_6', (0, 1)),
          ('AIG_7', (0, 1)),
          ('AIG_8', (0, 1)),
          ('AIG_9', (0, 1)),
          ('AIG_10', (0, 1)),
          ('AIG_11', (0, 1)),
          ('AIG_12', (0, 1)),
          ('AIG_13', (0, 1)),
          ('AIG_14', (0, 1)))),
 'AIL': ('sequence',
         (('AIL_1', (1, 1)),
          ('AIL_2', (0, 1)),
          ('AIL_3', (0, -1)),
          ('AIL_4', (0, 1)),
          ('AIL_5', (0, 1)),
          ('AIL_6', (0, 1)),
          ('AIL_7', (0, 1)),
          ('AIL_8', (0, 1)),
          ('AIL_9', (0, 1)),
          ('AIL_10', (0, 1)),
          ('AIL_11', (0, 1)),
          ('AIL_12', (0, 1)))),
 'AIP': ('sequence',
         (('AIP_1', (1, 1)),
          ('AIP_2', (0, 1)),
          ('AIP_3', (0, -1)),
          ('AIP_4', (0, 1)),
          ('AIP_5', (0, 1)),
          ('AIP_6', (0, 1)),
          ('AIP_7', (0, 1)),
          ('AIP_8', (0, 1)),
          ('AIP_9', (0, 1)),
          ('AIP_10', (0, 1)),
          ('AIP_11', (0, 1)),
          ('AIP_12', (0, 1)))),
 'AIS': ('sequence',
         (('AIS_1', (1, 1)),
          ('AIS_2', (0, 1)),
          ('AIS_3', (1, 1)),
          ('AIS_4', (0, 1)),
          ('AIS_5', (0, 1)),
          ('AIS_6', (0, 1)),
          ('AIS_7', (0, 1)),
          ('AIS_8', (0, 1)),
          ('AIS_9', (0, 1)),
          ('AIS_10', (0, 1)),
          ('AIS_11', (0, -1)),
          ('AIS_12', (0, -1)))),
 'AL1': ('sequence',
         (('AL1_1', (1, 1)),
          ('AL1_2', (0, 1)),
          ('AL1_3', (1, 1)),
          ('AL1_4', (0, 1)),
          ('AL1_5', (0, -1)),
          ('AL1_6', (0, 1)))),
 'ANYHL7SEGMENT': ('choice',
                   (('ABS', (0, -1)),
                    ('ACC', (0, -1)),
                    ('ADD', (0, -1)),
                    ('ADJ', (0, -1)),
                    ('AFF', (0, -1)),
                    ('AIG', (0, -1)),
                    ('AIL', (0, -1)),
                    ('AIP', (0, -1)),
                    ('AIS', (0, -1)),
                    ('AL1', (0, -1)),
                    ('APR', (0, -1)),
                    ('ARQ', (0, -1)),
                    ('ARV', (0, -1)),
                    ('AUT', (0, -1)),
                    ('BHS', (0, -1)),
                    ('BLC', (0, -1)),
                    ('BLG', (0, -1)),
                    ('BPO', (0, -1)),
                    ('BPX', (0, -1)),
                    ('BTS', (0, -1)),
                    ('BTX', (0, -1)),
                    ('CDM', (0, -1)),
                    ('CER', (0, -1)),
                    ('CM0', (0, -1)),
                    ('CM1', (0, -1)),
                    ('CM2', (0, -1)),
                    ('CNS', (0, -1)),
                    ('CON', (0, -1)),
                    ('CSP', (0, -1)),
                    ('CSR', (0, -1)),
                    ('CSS', (0, -1)),
                    ('CTD', (0, -1)),
                    ('CTI', (0, -1)),
                    ('DB1', (0, -1)),
                    ('DG1', (0, -1)),
                    ('DMI', (0, -1)),
                    ('DRG', (0, -1)),
                    ('DSC', (0, -1)),
                    ('DSP', (0, -1)),
                    ('ECD', (0, -1)),
                    ('ECR', (0, -1)),
                    ('EDU', (0, -1)),
                    ('EQP', (0, -1)),
                    ('EQU', (0, -1)),
                    ('ERR', (0, -1)),
                    ('EVN', (0, -1)),
                    ('FAC', (0, -1)),
                    ('FHS', (0, -1)),
                    ('FT1', (0, -1)),
                    ('FTS', (0, -1)),
                    ('GOL', (0, -1)),
                    ('GP1', (0, -1)),
                    ('GP2', (0, -1)),
                    ('GT1', (0, -1)),
                    ('IAM', (0, -1)),
                    ('IIM', (0, -1)),
                    ('ILT', (0, -1)),
                    ('IN1', (0, -1)),
                    ('IN2', (0, -1)),
                    ('IN3', (0, -1)),
                    ('INV', (0, -1)),
                    ('IPC', (0, -1)),
                    ('IPR', (0, -1)),
                    ('ISD', (0, -1)),
                    ('ITM', (0, -1)),
                    ('IVC', (0, -1)),
                    ('IVT', (0, -1)),
                    ('LAN', (0, -1)),
                    ('LCC', (0, -1)),
                    ('LCH', (0, -1)),
                    ('LDP', (0, -1)),
                    ('LOC', (0, -1)),
                    ('LRL', (0, -1)),
                    ('MFA', (0, -1)),
                    ('MFE', (0, -1)),
                    ('MFI', (0, -1)),
                    ('MRG', (0, -1)),
                    ('MSA', (0, -1)),
                    ('MSH', (0, -1)),
                    ('NCK', (0, -1)),
                    ('NDS', (0, -1)),
                    ('NK1', (0, -1)),
                    ('NPU', (0, -1)),
                    ('NSC', (0, -1)),
                    ('NST', (0, -1)),
                    ('NTE', (0, -1)),
                    ('OBR', (0, -1)),
                    ('OBX', (0, -1)),
                    ('ODS', (0, -1)),
                    ('ODT', (0, -1)),
                    ('OM1', (0, -1)),
                    ('OM2', (0, -1)),
                    ('OM3', (0, -1)),
                    ('OM4', (0, -1)),
                    ('OM5', (0, -1)),
                    ('OM6', (0, -1)),
                    ('OM7', (0, -1)),
                    ('ORC', (0, -1)),
                    ('ORG', (0, -1)),
                    ('OVR', (0, -1)),
                    ('PCE', (0, -1)),
                    ('PCR', (0, -1)),
                    ('PD1', (0, -1)),
                    ('PDA', (0, -1)),
                    ('PDC', (0, -1)),
                    ('PEO', (0, -1)),
                    ('PES', (0, -1)),
                    ('PID', (0, -1)),
                    ('PKG', (0, -1)),
                    ('PMT', (0, -1)),
                    ('PR1', (0, -1)),
                    ('PRA', (0, -1)),
                    ('PRB', (0, -1)),
                    ('PRC', (0, -1)),
                    ('PRD', (0, -1)),
                    ('PSG', (0, -1)),
                    ('PSH', (0, -1)),
                    ('PSL', (0, -1)),
                    ('PSS', (0, -1)),
                    ('PTH', (0, -1)),
                    ('PV1', (0, -1)),
                    ('PV2', (0, -1)),
                    ('PYE', (0, -1)),
                    ('QAK', (0, -1)),
                    ('QID', (0, -1)),
                    ('QPD', (0, -1)),
                    ('QRD', (0, -1)),
                    ('QRF', (0, -1)),
                    ('QRI', (0, -1)),
                    ('RCP', (0, -1)),
                    ('RDF', (0, -1)),
                    ('RDT', (0, -1)),
                    ('REL', (0, -1)),
                    ('RF1', (0, -1)),
                    ('RFI', (0, -1)),
                    ('RGS', (0, -1)),
                    ('RMI', (0, -1)),
                    ('ROL', (0, -1)),
                    ('RQ1', (0, -1)),
                    ('RQD', (0, -1)),
                    ('RXA', (0, -1)),
                    ('RXC', (0, -1)),
                    ('RXD', (0, -1)),
                    ('RXE', (0, -1)),
                    ('RXG', (0, -1)),
                    ('RXO', (0, -1)),
                    ('RXR', (0, -1)),
                    ('SAC', (0, -1)),
                    ('SCD', (0, -1)),
                    ('SCH', (0, -1)),
                    ('SCP', (0, -1)),
                    ('SDD', (0, -1)),
                    ('SFT', (0, -1)),
                    ('SID', (0, -1)),
                    ('SLT', (0, -1)),
                    ('SPM', (0, -1)),
                    ('STF', (0, -1)),
                    ('STZ', (0, -1)),
                    ('TCC', (0, -1)),
                    ('TCD', (0, -1)),
                    ('TQ1', (0, -1)),
                    ('TQ2', (0, -1)),
                    ('TXA', (0, -1)),
                    ('UAC', (0, -1)),
                    ('UB1', (0, -1)),
                    ('UB2', (0, -1)),
                    ('URD', (0, -1)),
                    ('URS', (0, -1)),
                    ('VAR', (0, -1)),
                    ('VND', (0, -1)))),
 'APR': ('sequence',
         (('APR_1', (0, -1)),
          ('APR_2', (0, -1)),
          ('APR_3', (0, -1)),
          ('APR_4', (0, 1)),
          ('APR_5', (0, -1)))),
 'ARQ': ('sequence',
         (('ARQ_1', (1, 1)),
          ('ARQ_2', (0, 1)),
          ('ARQ_3', (0, 1)),
          ('ARQ_4', (0, 1)),
          ('ARQ_5', (0, 1)),
          ('ARQ_6', (0, 1)),
          ('ARQ_7', (0, 1)),
          ('ARQ_8', (0, 1)),
          ('ARQ_9', (0, 1)),
          ('ARQ_10', (0, 1)),
          ('ARQ_11', (0, -1)),
          ('ARQ_12', (0, 1)),
          ('ARQ_13', (0, 1)),
          ('ARQ_14', (0, 1)),
          ('ARQ_15', (1, -1)),
          ('ARQ_16', (0, -1)),
          ('ARQ_17', (0, -1)),
          ('ARQ_18', (0, 1)),
          ('ARQ_19', (1, -1)),
          ('ARQ_20', (0, -1)),
          ('ARQ_21', (0, 1)),
          ('ARQ_22', (0, 1)),
          ('ARQ_23', (0, 1)),
          ('ARQ_24', (0, -1)),
          ('ARQ_25', (0, -1)))),
 'ARV': ('sequence',
         (('ARV_1', (0, 1)),
          ('ARV_2', (1, 1)),
          ('ARV_3', (1, 1)),
          ('ARV_4', (0, -1)),
          ('ARV_5', (0, -1)),
          ('ARV_6', (0, 1)))),
 'AUT': ('sequence',
         (('AUT_1', (0, 1)),
          ('AUT_2', (1, 1)),
          ('AUT_3', (0, 1)),
          ('AUT_4', (0, 1)),
          ('AUT_5', (0, 1)),
          ('AUT_6', (0, 1)),
          ('AUT_7', (0, 1)),
          ('AUT_8', (0, 1)),
          ('AUT_9', (0, 1)),
          ('AUT_10', (0, 1)))),
 'BHS': ('sequence',
         (('BHS_1', (1, 1)),
          ('BHS_2', (1, 1)),
          ('BHS_3', (0, 1)),
          ('BHS_4', (0, 1)),
          ('BHS_5', (0, 1)),
          ('BHS_6', (0, 1)),
          ('BHS_7', (0, 1)),
          ('BHS_8', (0, 1)),
          ('BHS_9', (0, 1)),
          ('BHS_10', (0, 1)),
          ('BHS_11', (0, 1)),
          ('BHS_12', (0, 1)),
          ('BHS_13', (0, 1)),
          ('BHS_14', (0, 1)))),
 'BLC': ('sequence', (('BLC_1', (0, 1)), ('BLC_2', (0, 1)))),
 'BLG': ('sequence',
         (('BLG_1', (0, 1)),
          ('BLG_2', (0, 1)),
          ('BLG_3', (0, 1)),
          ('BLG_4', (0, 1)))),
 'BPO': ('sequence',
         (('BPO_1', (1, 1)),
          ('BPO_2', (1, 1)),
          ('BPO_3', (0, -1)),
          ('BPO_4', (1, 1)),
          ('BPO_5', (0, 1)),
          ('BPO_6', (0, 1)),
          ('BPO_7', (0, 1)),
          ('BPO_8', (0, 1)),
          ('BPO_9', (0, 1)),
          ('BPO_10', (0, 1)),
          ('BPO_11', (0, 1)),
          ('BPO_12', (0, 1)),
          ('BPO_13', (0, -1)),
          ('BPO_14', (0, 1)))),
 'BPX': ('sequence',
         (('BPX_1', (1, 1)),
          ('BPX_2', (1, 1)),
          ('BPX_3', (1, 1)),
          ('BPX_4', (1, 1)),
          ('BPX_5', (0, 1)),
          ('BPX_6', (0, 1)),
          ('BPX_7', (0, 1)),
          ('BPX_8', (0, 1)),
          ('BPX_9', (0, 1)),
          ('BPX_10', (0, 1)),
          ('BPX_11', (0, 1)),
          ('BPX_12', (0, -1)),
          ('BPX_13', (0, 1)),
          ('BPX_14', (1, 1)),
          ('BPX_15', (0, 1)),
          ('BPX_16', (0, 1)),
          ('BPX_17', (0, 1)),
          ('BPX_18', (0, 1)),
          ('BPX_19', (0, 1)),
          ('BPX_20', (0, 1)),
          ('BPX_21', (0, 1)))),
 'BTS': ('sequence',
         (('BTS_1', (0, 1)), ('BTS_2', (0, 1)), ('BTS_3', (0, -1)))),
 'BTX': ('sequence',
         (('BTX_1', (1, 1)),
          ('BTX_2', (0, 1)),
          ('BTX_3', (0, 1)),
          ('BTX_4', (0, 1)),
          ('BTX_5', (0, 1)),
          ('BTX_6', (0, 1)),
          ('BTX_7', (0, 1)),
          ('BTX_8', (1, 1)),
          ('BTX_9', (0, 1)),
          ('BTX_10', (0, 1)),
          ('BTX_11', (1, 1)),
          ('BTX_12', (1, 1)),
          ('BTX_13', (1, 1)),
          ('BTX_14', (0, 1)),
          ('BTX_15', (0, 1)),
          ('BTX_16', (0, 1)),
          ('BTX_17', (0, 1)),
          ('BTX_18', (0, -1)),
          ('BTX_19', (0, 1)))),
 'CDM': ('sequence',
         (('CDM_1', (1, 1)),
          ('CDM_2', (0, -1)),
          ('CDM_3', (1, 1)),
          ('CDM_4', (0, 1)),
          ('CDM_5', (0, 1)),
          ('CDM_6', (0, -1)),
          ('CDM_7', (0, -1)),
          ('CDM_8', (0, 1)),
          ('CDM_9', (0, -1)),
          ('CDM_10', (0, 1)),
          ('CDM_11', (0, -1)),
          ('CDM_12', (0, -1)),
          ('CDM_13', (0, 1)))),
 'CER': ('sequence',
         (('CER_1', (1, 1)),
          ('CER_2', (0, 1)),
          ('CER_3', (0, 1)),
          ('CER_4', (0, 1)),
          ('CER_5', (0, 1)),
          ('CER_6', (0, 1)),
          ('CER_7', (0, 1)),
          ('CER_8', (0, 1)),
          ('CER_9', (0, 1)),
          ('CER_10', (0, 1)),
          ('CER_11', (0, 1)),
          ('CER_12', (0, 1)),
          ('CER_13', (1, 1)),
          ('CER_14', (0, -1)),
          ('CER_15', (0, 1)),
          ('CER_16', (0, 1)),
          ('CER_17', (0, 1)),
          ('CER_18', (0, -1)),
          ('CER_19', (0, 1)),
          ('CER_20', (0, 1)),
          ('CER_21', (0, 1)),
          ('CER_22', (0, -1)),
          ('CER_23', (0, 1)),
          ('CER_24', (0, 1)),
          ('CER_25', (0, 1)),
          ('CER_26', (0, 1)),
          ('CER_27', (0, 1)),
          ('CER_28', (0, 1)),
          ('CER_29', (0, 1)),
          ('CER_30', (0, 1)),
          ('CER_31', (0, 1)))),
 'CM0': ('sequence',
         (('CM0_1', (0, 1)),
          ('CM0_2', (1, 1)),
          ('CM0_3', (0, 3)),
          ('CM0_4', (1, 1)),
          ('CM0_5', (0, -1)),
          ('CM0_6', (0, 1)),
          ('CM0_7', (0, 1)),
          ('CM0_8', (0, 1)),
          ('CM0_9', (0, -1)),
          ('CM0_10', (0, 1)),
          ('CM0_11', (0, -1)))),
 'CM1': ('sequence',
         (('CM1_1', (1, 1)), ('CM1_2', (1, 1)), ('CM1_3', (1, 1)))),
 'CM2': ('sequence',
         (('CM2_1', (0, 1)),
          ('CM2_2', (1, 1)),
          ('CM2_3', (0, 1)),
          ('CM2_4', (1, 200)))),
 'CNS': ('sequence',
         (('CNS_1', (0, 1)),
          ('CNS_2', (0, 1)),
          ('CNS_3', (0, 1)),
          ('CNS_4', (0, 1)),
          ('CNS_5', (0, 1)),
          ('CNS_6', (0, 1)))),
 'CON': ('sequence',
         (('CON_1', (1, 1)),
          ('CON_2', (0, 1)),
          ('CON_3', (0, 1)),
          ('CON_4', (0, 1)),
          ('CON_5', (0, -1)),
          ('CON_6', (0, -1)),
          ('CON_7', (0, -1)),
          ('CON_8', (0, -1)),
          ('CON_9', (0, -1)),
          ('CON_10', (0, 1)),
          ('CON_11', (1, 1)),
          ('CON_12', (0, 1)),
          ('CON_13', (0, 1)),
          ('CON_14', (0, 1)),
          ('CON_15', (0, 1)),
          ('CON_16', (0, 1)),
          ('CON_17', (0, 1)),
          ('CON_18', (0, 1)),
          ('CON_19', (0, 1)),
          ('CON_20', (0, 1)),
          ('CON_21', (0, 1)),
          ('CON_22', (0, 1)),
          ('CON_23', (0, 1)),
          ('CON_24', (1, -1)),
          ('CON_25', (1, -1)))),
 'CSP': ('sequence',
         (('CSP_1', (1, 1)),
          ('CSP_2', (1, 1)),
          ('CSP_3', (0, 1)),
          ('CSP_4', (0, 1)))),
 'CSR': ('sequence',
         (('CSR_1', (1, 1)),
          ('CSR_2', (0, 1)),
          ('CSR_3', (0, 1)),
          ('CSR_4', (1, 1)),
          ('CSR_5', (0, 1)),
          ('CSR_6', (1, 1)),
          ('CSR_7', (0, -1)),
          ('CSR_8', (1, -1)),
          ('CSR_9', (0, 1)),
          ('CSR_10', (0, 1)),
          ('CSR_11', (0, 3)),
          ('CSR_12', (0, 3)),
          ('CSR_13', (0, 3)),
          ('CSR_14', (0, 1)),
          ('CSR_15', (0, 1)),
          ('CSR_16', (0, 1)))),
 'CSS': ('sequence',
         (('CSS_1', (1, 1)), ('CSS_2', (0, 1)), ('CSS_3', (0, 3)))),
 'CTD': ('sequence',
         (('CTD_1', (1, -1)),
          ('CTD_2', (0, -1)),
          ('CTD_3', (0, -1)),
          ('CTD_4', (0, 1)),
          ('CTD_5', (0, -1)),
          ('CTD_6', (0, 1)),
          ('CTD_7', (0, -1)))),
 'CTI': ('sequence',
         (('CTI_1', (1, 1)), ('CTI_2', (0, 1)), ('CTI_3', (0, 1)))),
 'DB1': ('sequence',
         (('DB1_1', (1, 1)),
          ('DB1_2', (0, 1)),
          ('DB1_3', (0, -1)),
          ('DB1_4', (0, 1)),
          ('DB1_5', (0, 1)),
          ('DB1_6', (0, 1)),
          ('DB1_7', (0, 1)),
          ('DB1_8', (0, 1)))),
 'DG1': ('sequence',
         (('DG1_1', (1, 1)),
          ('DG1_3', (1, 1)),
          ('DG1_5', (0, 1)),
          ('DG1_6', (1, 1)),
          ('DG1_15', (0, 1)),
          ('DG1_16', (0, -1)),
          ('DG1_17', (0, 1)),
          ('DG1_18', (0, 1)),
          ('DG1_19', (0, 1)),
          ('DG1_20', (0, 1)),
          ('DG1_21', (0, 1)),
          ('DG1_22', (0, 1)),
          ('DG1_23', (0, 1)),
          ('DG1_24', (0, 1)),
          ('DG1_25', (0, 1)),
          ('DG1_26', (0, 1)))),
 'DMI': ('sequence',
         (('DMI_1', (0, 1)),
          ('DMI_2', (0, 1)),
          ('DMI_3', (0, 1)),
          ('DMI_4', (0, 1)),
          ('DMI_5', (0, 1)))),
 'DRG': ('sequence',
         (('DRG_1', (0, 1)),
          ('DRG_2', (0, 1)),
          ('DRG_3', (0, 1)),
          ('DRG_4', (0, 1)),
          ('DRG_5', (0, 1)),
          ('DRG_6', (0, 1)),
          ('DRG_7', (0, 1)),
          ('DRG_8', (0, 1)),
          ('DRG_9', (0, 1)),
          ('DRG_10', (0, 1)),
          ('DRG_11', (0, 1)),
          ('DRG_12', (0, 1)),
          ('DRG_13', (0, 1)),
          ('DRG_14', (0, 1)),
          ('DRG_15', (0, 1)),
          ('DRG_16', (0, 1)),
          ('DRG_17', (0, 1)),
          ('DRG_18', (0, 1)),
          ('DRG_19', (0, 1)),
          ('DRG_20', (0, 1)),
          ('DRG_21', (0, 1)),
          ('DRG_22', (0, 1)),
          ('DRG_23', (0, 1)),
          ('DRG_24', (0, 1)),
          ('DRG_25', (0, 1)),
          ('DRG_26', (0, 1)),
          ('DRG_27', (0, 1)),
          ('DRG_28', (0, 1)),
          ('DRG_29', (0, 1)),
          ('DRG_30', (0, 1)),
          ('DRG_31', (0, 1)),
          ('DRG_32', (0, 1)),
          ('DRG_33', (0, 1)))),
 'DSC': ('sequence', (('DSC_1', (0, 1)), ('DSC_2', (0, 1)))),
 'DSP': ('sequence',
         (('DSP_1', (0, 1)),
          ('DSP_2', (0, 1)),
          ('DSP_3', (1, 1)),
          ('DSP_4', (0, 1)),
          ('DSP_5', (0, 1)))),
 'ECD': ('sequence',
         (('ECD_1', (1, 1)),
          ('ECD_2', (1, 1)),
          ('ECD_3', (0, 1)),
          ('ECD_4', (0, 1)),
          ('ECD_5', (0, -1)))),
 'ECR': ('sequence',
         (('ECR_1', (1, 1)), ('ECR_2', (1, 1)), ('ECR_3', (0, -1)))),
 'EDU': ('sequence',
         (('EDU_1', (1, 1)),
          ('EDU_2', (0, 1)),
          ('EDU_3', (0, 1)),
          ('EDU_4', (0, 1)),
          ('EDU_5', (0, 1)),
          ('EDU_6', (0, 1)),
          ('EDU_7', (0, 1)),
          ('EDU_8', (0, 1)),
          ('EDU_9', (0, -1)))),
 'EQP': ('sequence',
         (('EQP_1', (1, 1)),
          ('EQP_2', (0, 1)),
          ('EQP_3', (1, 1)),
          ('EQP_4', (0, 1)),
          ('EQP_5', (1, 1)))),
 'EQU': ('sequence',
         (('EQU_1', (1, 1)),
          ('EQU_2', (1, 1)),
          ('EQU_3', (0, 1)),
          ('EQU_4', (0, 1)),
          ('EQU_5', (0, 1)))),
 'ERR': ('sequence',
         (('ERR_1', (0, -1)),
          ('ERR_2', (0, -1)),
          ('ERR_3', (1, 1)),
          ('ERR_4', (1, 1)),
          ('ERR_5', (0, 1)),
          ('ERR_6', (0, 10)),
          ('ERR_7', (0, 1)),
          ('ERR_8', (0, 1)),
          ('ERR_9', (0, -1)),
          ('ERR_10', (0, 1)),
          ('ERR_11', (0, -1)),
          ('ERR_12', (0, -1)))),
 'EVN': ('sequence',
         (('EVN_1', (0, 1)),
          ('EVN_2', (1, 1)),
          ('EVN_3', (0, 1)),
          ('EVN_4', (0, 1)),
          ('EVN_5', (0, -1)),
          ('EVN_6', (0, 1)),
          ('EVN_7', (0, 1)))),
 'FAC': ('sequence',
         (('FAC_1', (1, 1)),
          ('FAC_2', (0, 1)),
          ('FAC_3', (1, -1)),
          ('FAC_4', (1, 1)),
          ('FAC_5', (0, -1)),
          ('FAC_6', (0, -1)),
          ('FAC_7', (0, -1)),
          ('FAC_8', (0, -1)),
          ('FAC_9', (1, -1)),
          ('FAC_10', (0, 1)),
          ('FAC_11', (0, -1)),
          ('FAC_12', (0, 1)))),
 'FHS': ('sequence',
         (('FHS_1', (1, 1)),
          ('FHS_2', (1, 1)),
          ('FHS_3', (0, 1)),
          ('FHS_4', (0, 1)),
          ('FHS_5', (0, 1)),
          ('FHS_6', (0, 1)),
          ('FHS_7', (0, 1)),
          ('FHS_8', (0, 1)),
          ('FHS_9', (0, 1)),
          ('FHS_10', (0, 1)),
          ('FHS_11', (0, 1)),
          ('FHS_12', (0, 1)),
          ('FHS_13', (0, 1)),
          ('FHS_14', (0, 1)))),
 'FT1': ('sequence',
         (('FT1_1', (0, 1)),
          ('FT1_2', (0, 1)),
          ('FT1_3', (0, 1)),
          ('FT1_4', (1, 1)),
          ('FT1_5', (0, 1)),
          ('FT1_6', (1, 1)),
          ('FT1_7', (1, 1)),
          ('FT1_10', (0, 1)),
          ('FT1_11', (0, 1)),
          ('FT1_12', (0, 1)),
          ('FT1_13', (0, 1)),
          ('FT1_14', (0, 1)),
          ('FT1_15', (0, 1)),
          ('FT1_16', (0, 1)),
          ('FT1_17', (0, 1)),
          ('FT1_18', (0, 1)),
          ('FT1_19', (0, -1)),
          ('FT1_20', (0, -1)),
          ('FT1_21', (0, -1)),
          ('FT1_22', (0, 1)),
          ('FT1_23', (0, 1)),
          ('FT1_24', (0, -1)),
          ('FT1_25', (0, 1)),
          ('FT1_26', (0, -1)),
          ('FT1_27', (0, 1)),
          ('FT1_28', (0, 1)),
          ('FT1_29', (0, 1)),
          ('FT1_30', (0, 1)),
          ('FT1_31', (0, -1)))),
 'FTS': ('sequence', (('FTS_1', (0, 1)), ('FTS_2', (0, 1)))),
 'GOL': ('sequence',
         (('GOL_1', (1, 1)),
          ('GOL_2', (1, 1)),
          ('GOL_3', (1, 1)),
          ('GOL_4', (1, 1)),
          ('GOL_5', (0, 1)),
          ('GOL_6', (0, 1)),
          ('GOL_7', (0, 1)),
          ('GOL_8', (0, 1)),
          ('GOL_9', (0, 1)),
          ('GOL_10', (0, 1)),
          ('GOL_11', (0, 1)),
          ('GOL_12', (0, 1)),
          ('GOL_13', (0, 1)),
          ('GOL_14', (0, 1)),
          ('GOL_15', (0, 1)),
          ('GOL_16', (0, 1)),
          ('GOL_17', (0, -1)),
          ('GOL_18', (0, 1)),
          ('GOL_19', (0, 1)),
          ('GOL_20', (0, -1)),
          ('GOL_21', (0, -1)),
          ('GOL_22', (0, 1)))),
 'GP1': ('sequence',
         (('GP1_1', (1, 1)),
          ('GP1_2', (0, -1)),
          ('GP1_3', (0, 1)),
          ('GP1_4', (0, -1)),
          ('GP1_5', (0, 1)))),
 'GP2': ('sequence',
         (('GP2_1', (0, 1)),
          ('GP2_2', (0, 1)),
          ('GP2_3', (0, 1)),
          ('GP2_4', (0, 1)),
          ('GP2_5', (0, 1)),
          ('GP2_6', (0, -1)),
          ('GP2_7', (0, 1)),
          ('GP2_8', (0, -1)),
          ('GP2_9', (0, 1)),
          ('GP2_10', (0, 1)),
          ('GP2_11', (0, 1)),
          ('GP2_12', (0, 1)),
          ('GP2_13', (0, 1)),
          ('GP2_14', (0, 1)))),
 'GT1': ('sequence',
         (('GT1_1', (1, 1)),
          ('GT1_2', (0, -1)),
          ('GT1_3', (1, -1)),
          ('GT1_4', (0, -1)),
          ('GT1_5', (0, -1)),
          ('GT1_6', (0, -1)),
          ('GT1_7', (0, -1)),
          ('GT1_8', (0, 1)),
          ('GT1_9', (0, 1)),
          ('GT1_10', (0, 1)),
          ('GT1_11', (0, 1)),
          ('GT1_12', (0, 1)),
          ('GT1_13', (0, 1)),
          ('GT1_14', (0, 1)),
          ('GT1_15', (0, 1)),
          ('GT1_16', (0, -1)),
          ('GT1_17', (0, -1)),
          ('GT1_18', (0, -1)),
          ('GT1_19', (0, -1)),
          ('GT1_20', (0, 1)),
          ('GT1_21', (0, -1)),
          ('GT1_22', (0, 1)),
          ('GT1_23', (0, 1)),
          ('GT1_24', (0, 1)),
          ('GT1_25', (0, 1)),
          ('GT1_26', (0, 1)),
          ('GT1_27', (0, 1)),
          ('GT1_28', (0, 1)),
          ('GT1_29', (0, -1)),
          ('GT1_30', (0, 1)),
          ('GT1_31', (0, 1)),
          ('GT1_32', (0, 1)),
          ('GT1_33', (0, 1)),
          ('GT1_34', (0, -1)),
          ('GT1_35', (0, -1)),
          ('GT1_36', (0, 1)),
          ('GT1_37', (0, 1)),
          ('GT1_38', (0, 1)),
          ('GT1_39', (0, 1)),
          ('GT1_40', (0, 1)),
          ('GT1_41', (0, 1)),
          ('GT1_42', (0, -1)),
          ('GT1_43', (0, 1)),
          ('GT1_44', (0, -1)),
          ('GT1_45', (0, -1)),
          ('GT1_46', (0, -1)),
          ('GT1_47', (0, 1)),
          ('GT1_48', (0, 1)),
          ('GT1_49', (0, 1)),
          ('GT1_50', (0, 1)),
          ('GT1_51', (0, -1)),
          ('GT1_52', (0, 1)),
          ('GT1_53', (0, 1)),
          ('GT1_54', (0, 1)),
          ('GT1_55', (0, -1)),
          ('GT1_56', (0, 1)),
          ('GT1_57', (0, 1)))),
 'IAM': ('sequence',
         (('IAM_1', (1, 1)),
          ('IAM_2', (0, 1)),
          ('IAM_3', (1, 1)),
          ('IAM_4', (0, 1)),
          ('IAM_5', (0, -1)),
          ('IAM_6', (1, 1)),
          ('IAM_7', (0, 1)),
          ('IAM_8', (0, 1)),
          ('IAM_9', (0, 1)),
          ('IAM_10', (0, 1)),
          ('IAM_11', (0, 1)),
          ('IAM_12', (0, 1)),
          ('IAM_13', (0, 1)),
          ('IAM_14', (0, 1)),
          ('IAM_15', (0, 1)),
          ('IAM_16', (0, 1)),
          ('IAM_17', (0, 1)),
          ('IAM_18', (0, 1)),
          ('IAM_19', (0, 1)),
          ('IAM_20', (0, 1)))),
 'IIM': ('sequence',
         (('IIM_1', (1, 1)),
          ('IIM_2', (1, 1)),
          ('IIM_3', (0, 1)),
          ('IIM_4', (0, 1)),
          ('IIM_5', (0, 1)),
          ('IIM_6', (0, 1)),
          ('IIM_7', (0, 1)),
          ('IIM_8', (0, 1)),
          ('IIM_9', (0, 1)),
          ('IIM_10', (0, 1)),
          ('IIM_11', (0, 1)),
          ('IIM_12', (0, 1)),
          ('IIM_13', (0, 1)),
          ('IIM_14', (0, 1)),
          ('IIM_15', (0, -1)))),
 'ILT': ('sequence',
         (('ILT_1', (1, 1)),
          ('ILT_2', (1, 1)),
          ('ILT_3', (0, 1)),
          ('ILT_4', (0, 1)),
          ('ILT_5', (0, 1)),
          ('ILT_6', (0, 1)),
          ('ILT_7', (0, 1)),
          ('ILT_8', (0, 1)),
          ('ILT_9', (0, 1)),
          ('ILT_10', (0, 1)))),
 'IN1': ('sequence',
         (('IN1_1', (1, 1)),
          ('IN1_2', (1, 1)),
          ('IN1_3', (1, -1)),
          ('IN1_4', (0, -1)),
          ('IN1_5', (0, -1)),
          ('IN1_6', (0, -1)),
          ('IN1_7', (0, -1)),
          ('IN1_8', (0, 1)),
          ('IN1_9', (0, -1)),
          ('IN1_10', (0, -1)),
          ('IN1_11', (0, -1)),
          ('IN1_12', (0, 1)),
          ('IN1_13', (0, 1)),
          ('IN1_14', (0, 1)),
          ('IN1_15', (0, 1)),
          ('IN1_16', (0, -1)),
          ('IN1_17', (0, 1)),
          ('IN1_18', (0, 1)),
          ('IN1_19', (0, -1)),
          ('IN1_20', (0, 1)),
          ('IN1_21', (0, 1)),
          ('IN1_22', (0, 1)),
          ('IN1_23', (0, 1)),
          ('IN1_24', (0, 1)),
          ('IN1_25', (0, 1)),
          ('IN1_26', (0, 1)),
          ('IN1_27', (0, 1)),
          ('IN1_28', (0, 1)),
          ('IN1_29', (0, 1)),
          ('IN1_30', (0, -1)),
          ('IN1_31', (0, 1)),
          ('IN1_32', (0, 1)),
          ('IN1_33', (0, 1)),
          ('IN1_34', (0, 1)),
          ('IN1_35', (0, 1)),
          ('IN1_36', (0, 1)),
          ('IN1_37', (0, 1)),
          ('IN1_39', (0, 1)),
          ('IN1_42', (0, 1)),
          ('IN1_43', (0, 1)),
          ('IN1_44', (0, -1)),
          ('IN1_45', (0, 1)),
          ('IN1_46', (0, 1)),
          ('IN1_47', (0, 1)),
          ('IN1_48', (0, 1)),
          ('IN1_49', (0, -1)),
          ('IN1_50', (0, 1)),
          ('IN1_51', (0, 1)),
          ('IN1_52', (0, 1)),
          ('IN1_53', (0, 1)))),
 'IN2': ('sequence',
         (('IN2_1', (0, -1)),
          ('IN2_2', (0, 1)),
          ('IN2_3', (0, -1)),
          ('IN2_4', (0, 1)),
          ('IN2_5', (0, -1)),
          ('IN2_6', (0, 1)),
          ('IN2_7', (0, -1)),
          ('IN2_8', (0, 1)),
          ('IN2_9', (0, -1)),
          ('IN2_10', (0, 1)),
          ('IN2_11', (0, 1)),
          ('IN2_12', (0, 1)),
          ('IN2_13', (0, 1)),
          ('IN2_14', (0, 1)),
          ('IN2_15', (0, 1)),
          ('IN2_16', (0, 1)),
          ('IN2_17', (0, 1)),
          ('IN2_18', (0, 1)),
          ('IN2_19', (0, 1)),
          ('IN2_20', (0, 1)),
          ('IN2_21', (0, 1)),
          ('IN2_22', (0, -1)),
          ('IN2_23', (0, 1)),
          ('IN2_24', (0, -1)),
          ('IN2_25', (0, -1)),
          ('IN2_26', (0, -1)),
          ('IN2_27', (0, 1)),
          ('IN2_28', (0, -1)),
          ('IN2_29', (0, -1)),
          ('IN2_30', (0, 1)),
          ('IN2_31', (0, 1)),
          ('IN2_32', (0, -1)),
          ('IN2_33', (0, -1)),
          ('IN2_34', (0, 1)),
          ('IN2_35', (0, 1)),
          ('IN2_36', (0, 1)),
          ('IN2_37', (0, 1)),
          ('IN2_38', (0, 1)),
          ('IN2_39', (0, 1)),
          ('IN2_40', (0, -1)),
          ('IN2_41', (0, 1)),
          ('IN2_42', (0, -1)),
          ('IN2_43', (0, -1)),
          ('IN2_44', (0, 1)),
          ('IN2_45', (0, 1)),
          ('IN2_46', (0, 1)),
          ('IN2_47', (0, 1)),
          ('IN2_48', (0, 1)),
          ('IN2_49', (0, -1)),
          ('IN2_50', (0, -1)),
          ('IN2_51', (0, 1)),
          ('IN2_52', (0, -1)),
          ('IN2_53', (0, -1)),
          ('IN2_54', (0, -1)),
          ('IN2_55', (0, 1)),
          ('IN2_56', (0, -1)),
          ('IN2_57', (0, 1)),
          ('IN2_58', (0, -1)),
          ('IN2_59', (0, 1)),
          ('IN2_60', (0, 1)),
          ('IN2_61', (0, 1)),
          ('IN2_62', (0, 1)),
          ('IN2_63', (0, -1)),
          ('IN2_64', (0, -1)),
          ('IN2_65', (0, 1)),
          ('IN2_66', (0, 1)),
          ('IN2_67', (0, 1)),
          ('IN2_68', (0, 1)),
          ('IN2_69', (0, -1)),
          ('IN2_70', (0, -1)),
          ('IN2_71', (0, -1)),
          ('IN2_72', (0, 1)))),
 'IN3': ('sequence',
         (('IN3_1', (1, 1)),
          ('IN3_2', (0, 1)),
          ('IN3_3', (0, -1)),
          ('IN3_4', (0, 1)),
          ('IN3_5', (0, 1)),
          ('IN3_6', (0, 1)),
          ('IN3_7', (0, 1)),
          ('IN3_8', (0, -1)),
          ('IN3_9', (0, 1)),
          ('IN3_10', (0, 1)),
          ('IN3_11', (0, 1)),
          ('IN3_12', (0, 1)),
          ('IN3_13', (0, 1)),
          ('IN3_14', (0, -1)),
          ('IN3_15', (0, 1)),
          ('IN3_16', (0, -1)),
          ('IN3_17', (0, 1)),
          ('IN3_18', (0, 1)),
          ('IN3_19', (0, -1)),
          ('IN3_20', (0, -1)),
          ('IN3_21', (0, 1)),
          ('IN3_22', (0, 1)),
          ('IN3_23', (0, 1)),
          ('IN3_24', (0, -1)),
          ('IN3_25', (0, -1)))),
 'INV': ('sequence',
         (('INV_1', (1, 1)),
          ('INV_2', (1, -1)),
          ('INV_3', (0, 1)),
          ('INV_4', (0, 1)),
          ('INV_5', (0, 1)),
          ('INV_6', (0, 1)),
          ('INV_7', (0, 1)),
          ('INV_8', (0, 1)),
          ('INV_9', (0, 1)),
          ('INV_10', (0, 1)),
          ('INV_11', (0, 1)),
          ('INV_12', (0, 1)),
          ('INV_13', (0, 1)),
          ('INV_14', (0, 1)),
          ('INV_15', (0, -1)),
          ('INV_16', (0, 1)),
          ('INV_17', (0, 1)),
          ('INV_18', (0, 1)),
          ('INV_19', (0, 1)),
          ('INV_20', (0, 1)))),
 'IPC': ('sequence',
         (('IPC_1', (1, 1)),
          ('IPC_2', (1, 1)),
          ('IPC_3', (1, 1)),
          ('IPC_4', (1, 1)),
          ('IPC_5', (0, 1)),
          ('IPC_6', (0, -1)),
          ('IPC_7', (0, 1)),
          ('IPC_8', (0, -1)),
          ('IPC_9', (0, 1)))),
 'IPR': ('sequence',
         (('IPR_1', (1, 1)),
          ('IPR_2', (1, 1)),
          ('IPR_3', (1, 1)),
          ('IPR_4', (1, 1)),
          ('IPR_5', (1, 1)),
          ('IPR_6', (0, 1)),
          ('IPR_7', (0, 1)),
          ('IPR_8', (1, 1)))),
 'ISD': ('sequence',
         (('ISD_1', (1, 1)), ('ISD_2', (0, 1)), ('ISD_3', (1, 1)))),
 'ITM': ('sequence',
         (('ITM_1', (1, 1)),
          ('ITM_2', (0, 1)),
          ('ITM_3', (0, 1)),
          ('ITM_4', (0, 1)),
          ('ITM_5', (0, 1)),
          ('ITM_6', (0, 1)),
          ('ITM_7', (0, 1)),
          ('ITM_8', (0, 1)),
          ('ITM_9', (0, 1)),
          ('ITM_10', (0, 1)),
          ('ITM_11', (0, 1)),
          ('ITM_12', (0, 1)),
          ('ITM_13', (0, 1)),
          ('ITM_14', (0, 1)),
          ('ITM_15', (0, 1)),
          ('ITM_16', (0, -1)),
          ('ITM_17', (0, 1)),
          ('ITM_18', (0, -1)),
          ('ITM_19', (0, 1)),
          ('ITM_20', (0, 1)),
          ('ITM_21', (0, 1)),
          ('ITM_22', (0, 1)),
          ('ITM_23', (0, 1)),
          ('ITM_24', (0, 1)),
          ('ITM_25', (0, 1)),
          ('ITM_26', (0, 1)),
          ('ITM_27', (0, 1)),
          ('ITM_28', (0, -1)),
          ('ITM_29', (0, 1)))),
 'IVC': ('sequence',
         (('IVC_1', (1, 1)),
          ('IVC_2', (0, 1)),
          ('IVC_3', (0, 1)),
          ('IVC_4', (1, 1)),
          ('IVC_5', (1, 1)),
          ('IVC_6', (1, 1)),
          ('IVC_7', (1, 1)),
          ('IVC_8', (1, 1)),
          ('IVC_9', (0, 1)),
          ('IVC_10', (1, 1)),
          ('IVC_11', (1, 1)),
          ('IVC_12', (0, 1)),
          ('IVC_13', (0, 1)),
          ('IVC_14', (0, 1)),
          ('IVC_15', (0, 1)),
          ('IVC_16', (0, 1)),
          ('IVC_17', (0, 1)),
          ('IVC_18', (0, 1)),
          ('IVC_19', (0, 1)),
          ('IVC_20', (0, 1)),
          ('IVC_21', (0, 1)),
          ('IVC_22', (0, 1)),
          ('IVC_23', (0, 1)),
          ('IVC_24', (0, -1)),
          ('IVC_25', (1, 1)),
          ('IVC_26', (0, 1)),
          ('IVC_27', (0, 1)),
          ('IVC_28', (0, 1)),
          ('IVC_29', (0, 1)),
          ('IVC_30', (0, 1)))),
 'IVT': ('sequence',
         (('IVT_1', (1, 1)),
          ('IVT_2', (1, 1)),
          ('IVT_3', (0, 1)),
          ('IVT_4', (0, 1)),
          ('IVT_5', (0, 1)),
          ('IVT_6', (0, 1)),
          ('IVT_7', (0, -1)),
          ('IVT_8', (0, 1)),
          ('IVT_9', (0, 1)),
          ('IVT_10', (0, 1)),
          ('IVT_11', (0, 1)),
          ('IVT_12', (0, 1)),
          ('IVT_13', (0, 1)),
          ('IVT_14', (0, 1)),
          ('IVT_15', (0, 1)),
          ('IVT_16', (0, 1)),
          ('IVT_17', (0, 1)),
          ('IVT_18', (0, 1)),
          ('IVT_19', (0, -1)),
          ('IVT_20', (0, 1)),
          ('IVT_21', (0, 1)),
          ('IVT_22', (0, 1)),
          ('IVT_23', (0, 1)),
          ('IVT_24', (0, 1)),
          ('IVT_25', (0, 1)),
          ('IVT_26', (0, 1)))),
 'LAN': ('sequence',
         (('LAN_1', (1, 1)),
          ('LAN_2', (1, 1)),
          ('LAN_3', (0, -1)),
          ('LAN_4', (0, 1)))),
 'LCC': ('sequence',
         (('LCC_1', (1, 1)),
          ('LCC_2', (1, 1)),
          ('LCC_3', (0, -1)),
          ('LCC_4', (1, -1)))),
 'LCH': ('sequence',
         (('LCH_1', (1, 1)),
          ('LCH_2', (0, 1)),
          ('LCH_3', (0, 1)),
          ('LCH_4', (1, 1)),
          ('LCH_5', (1, 1)))),
 'LDP': ('sequence',
         (('LDP_1', (1, 1)),
          ('LDP_2', (1, 1)),
          ('LDP_3', (0, -1)),
          ('LDP_4', (0, -1)),
          ('LDP_5', (0, -1)),
          ('LDP_6', (0, 1)),
          ('LDP_7', (0, 1)),
          ('LDP_8', (0, 1)),
          ('LDP_9', (0, 1)),
          ('LDP_10', (0, -1)),
          ('LDP_11', (0, 1)),
          ('LDP_12', (0, 1)))),
 'LOC': ('sequence',
         (('LOC_1', (1, 1)),
          ('LOC_2', (0, 1)),
          ('LOC_3', (1, -1)),
          ('LOC_4', (0, -1)),
          ('LOC_5', (0, -1)),
          ('LOC_6', (0, -1)),
          ('LOC_7', (0, -1)),
          ('LOC_8', (0, -1)),
          ('LOC_9', (0, 1)))),
 'LRL': ('sequence',
         (('LRL_1', (1, 1)),
          ('LRL_2', (0, 1)),
          ('LRL_3', (0, 1)),
          ('LRL_4', (1, 1)),
          ('LRL_5', (0, -1)),
          ('LRL_6', (0, 1)))),
 'MFA': ('sequence',
         (('MFA_1', (1, 1)),
          ('MFA_2', (0, 1)),
          ('MFA_3', (0, 1)),
          ('MFA_4', (1, 1)),
          ('MFA_5', (1, -1)),
          ('MFA_6', (1, -1)))),
 'MFE': ('sequence',
         (('MFE_1', (1, 1)),
          ('MFE_2', (0, 1)),
          ('MFE_3', (0, 1)),
          ('MFE_4', (1, -1)),
          ('MFE_5', (1, -1)),
          ('MFE_6', (0, 1)),
          ('MFE_7', (0, 1)))),
 'MFI': ('sequence',
         (('MFI_1', (1, 1)),
          ('MFI_2', (0, -1)),
          ('MFI_3', (1, 1)),
          ('MFI_4', (0, 1)),
          ('MFI_5', (0, 1)),
          ('MFI_6', (1, 1)))),
 'MRG': ('sequence',
         (('MRG_1', (1, -1)),
          ('MRG_2', (0, -1)),
          ('MRG_3', (0, 1)),
          ('MRG_4', (0, 1)),
          ('MRG_5', (0, 1)),
          ('MRG_6', (0, 1)),
          ('MRG_7', (0, -1)))),
 'MSA': ('sequence',
         (('MSA_1', (1, 1)),
          ('MSA_2', (1, 1)),
          ('MSA_3', (0, 1)),
          ('MSA_4', (0, 1)),
          ('MSA_6', (0, 1)),
          ('MSA_7', (0, 1)),
          ('MSA_8', (0, 1)))),
 'MSH': ('sequence',
         (('MSH_1', (1, 1)),
          ('MSH_2', (1, 1)),
          ('MSH_3', (0, 1)),
          ('MSH_4', (0, 1)),
          ('MSH_5', (0, 1)),
          ('MSH_6', (0, 1)),
          ('MSH_7', (1, 1)),
          ('MSH_8', (0, 1)),
          ('MSH_9', (1, 1)),
          ('MSH_10', (1, 1)),
          ('MSH_11', (1, 1)),
          ('MSH_12', (1, 1)),
          ('MSH_13', (0, 1)),
          ('MSH_14', (0, 1)),
          ('MSH_15', (0, 1)),
          ('MSH_16', (0, 1)),
          ('MSH_17', (0, 1)),
          ('MSH_18', (0, -1)),
          ('MSH_19', (0, 1)),
          ('MSH_20', (0, 1)),
          ('MSH_21', (0, -1)),
          ('MSH_22', (0, 1)),
          ('MSH_23', (0, 1)),
          ('MSH_24', (0, 1)),
          ('MSH_25', (0, 1)))),
 'NCK': ('sequence', (('NCK_1', (1, 1)),)),
 'NDS': ('sequence',
         (('NDS_1', (1, 1)),
          ('NDS_2', (1, 1)),
          ('NDS_3', (1, 1)),
          ('NDS_4', (1, 1)))),
 'NK1': ('sequence',
         (('NK1_1', (1, 1)),
          ('NK1_2', (0, -1)),
          ('NK1_3', (0, 1)),
          ('NK1_4', (0, -1)),
          ('NK1_5', (0, -1)),
          ('NK1_6', (0, -1)),
          ('NK1_7', (0, 1)),
          ('NK1_8', (0, 1)),
          ('NK1_9', (0, 1)),
          ('NK1_10', (0, 1)),
          ('NK1_11', (0, 1)),
          ('NK1_12', (0, 1)),
          ('NK1_13', (0, -1)),
          ('NK1_14', (0, 1)),
          ('NK1_15', (0, 1)),
          ('NK1_16', (0, 1)),
          ('NK1_17', (0, -1)),
          ('NK1_18', (0, -1)),
          ('NK1_19', (0, -1)),
          ('NK1_20', (0, 1)),
          ('NK1_21', (0, 1)),
          ('NK1_22', (0, 1)),
          ('NK1_23', (0, 1)),
          ('NK1_24', (0, 1)),
          ('NK1_25', (0, 1)),
          ('NK1_26', (0, -1)),
          ('NK1_27', (0, 1)),
          ('NK1_28', (0, -1)),
          ('NK1_29', (0, -1)),
          ('NK1_30', (0, -1)),
          ('NK1_31', (0, -1)),
          ('NK1_32', (0, -1)),
          ('NK1_33', (0, -1)),
          ('NK1_34', (0, 1)),
          ('NK1_35', (0, -1)),
          ('NK1_36', (0, 1)),
          ('NK1_37', (0, 1)),
          ('NK1_38', (0, 1)),
          ('NK1_39', (0, 1)))),
 'NPU': ('sequence', (('NPU_1', (1, 1)), ('NPU_2', (0, 1)))),
 'NSC': ('sequence',
         (('NSC_1', (1, 1)),
          ('NSC_2', (0, 1)),
          ('NSC_3', (0, 1)),
          ('NSC_4', (0, 1)),
          ('NSC_5', (0, 1)),
          ('NSC_6', (0, 1)),
          ('NSC_7', (0, 1)),
          ('NSC_8', (0, 1)),
          ('NSC_9', (0, 1)))),
 'NST': ('sequence',
         (('NST_1', (1, 1)),
          ('NST_2', (0, 1)),
          ('NST_3', (0, 1)),
          ('NST_4', (0, 1)),
          ('NST_5', (0, 1)),
          ('NST_6', (0, 1)),
          ('NST_7', (0, 1)),
          ('NST_8', (0, 1)),
          ('NST_9', (0, 1)),
          ('NST_10', (0, 1)),
          ('NST_11', (0, 1)),
          ('NST_12', (0, 1)),
          ('NST_13', (0, 1)),
          ('NST_14', (0, 1)),
          ('NST_15', (0, 1)))),
 'NTE': ('sequence',
         (('NTE_1', (0, 1)),
          ('NTE_2', (0, 1)),
          ('NTE_3', (0, -1)),
          ('NTE_4', (0, 1)),
          ('NTE_5', (0, 1)),
          ('NTE_6', (0, 1)),
          ('NTE_7', (0, 1)),
          ('NTE_8', (0, 1)))),
 'OBR': ('sequence',
         (('OBR_1', (0, 1)),
          ('OBR_2', (0, 1)),
          ('OBR_3', (0, 1)),
          ('OBR_4', (1, 1)),
          ('OBR_5', (0, 1)),
          ('OBR_6', (0, 1)),
          ('OBR_7', (0, 1)),
          ('OBR_8', (0, 1)),
          ('OBR_9', (0, 1)),
          ('OBR_10', (0, -1)),
          ('OBR_11', (0, 1)),
          ('OBR_12', (0, 1)),
          ('OBR_13', (0, 1)),
          ('OBR_14', (0, 1)),
          ('OBR_15', (0, 1)),
          ('OBR_16', (0, -1)),
          ('OBR_17', (0, 2)),
          ('OBR_18', (0, 1)),
          ('OBR_19', (0, 1)),
          ('OBR_20', (0, 1)),
          ('OBR_21', (0, 1)),
          ('OBR_22', (0, 1)),
          ('OBR_23', (0, 1)),
          ('OBR_24', (0, 1)),
          ('OBR_25', (0, 1)),
          ('OBR_26', (0, 1)),
          ('OBR_27', (0, -1)),
          ('OBR_28', (0, -1)),
          ('OBR_29', (0, 1)),
          ('OBR_30', (0, 1)),
          ('OBR_31', (0, -1)),
          ('OBR_32', (0, 1)),
          ('OBR_33', (0, -1)),
          ('OBR_34', (0, -1)),
          ('OBR_35', (0, -1)),
          ('OBR_36', (0, 1)),
          ('OBR_37', (0, 1)),
          ('OBR_38', (0, -1)),
          ('OBR_39', (0, -1)),
          ('OBR_40', (0, 1)),
          ('OBR_41', (0, 1)),
          ('OBR_42', (0, 1)),
          ('OBR_43', (0, -1)),
          ('OBR_44', (0, 1)),
          ('OBR_45', (0, -1)),
          ('OBR_46', (0, -1)),
          ('OBR_47', (0, -1)),
          ('OBR_48', (0, 1)),
          ('OBR_49', (0, 1)),
          ('OBR_50', (0, 1)))),
 'OBX': ('sequence',
         (('OBX_1', (0, 1)),
          ('OBX_2', (0, 1)),
          ('OBX_3', (1, 1)),
          ('OBX_4', (0, 1)),
          ('OBX_5', (0, -1)),
          ('OBX_6', (0, 1)),
          ('OBX_7', (0, 1)),
          ('OBX_8', (0, -1)),
          ('OBX_9', (0, 1)),
          ('OBX_10', (0, -1)),
          ('OBX_11', (1, 1)),
          ('OBX_12', (0, 1)),
          ('OBX_13', (0, 1)),
          ('OBX_14', (0, 1)),
          ('OBX_15', (0, 1)),
          ('OBX_16', (0, -1)),
          ('OBX_17', (0, -1)),
          ('OBX_18', (0, -1)),
          ('OBX_19', (0, 1)),
          ('OBX_20', (0, -1)),
          ('OBX_21', (0, 1)),
          ('OBX_22', (0, 1)),
          ('OBX_23', (0, -1)),
          ('OBX_24', (0, -1)),
          ('OBX_25', (0, -1)))),
 'ODS': ('sequence',
         (('ODS_1', (1, 1)),
          ('ODS_2', (0, 10)),
          ('ODS_3', (1, 20)),
          ('ODS_4', (0, 2)))),
 'ODT': ('sequence',
         (('ODT_1', (1, 1)), ('ODT_2', (0, 10)), ('ODT_3', (0, 1)))),
 'OM1': ('sequence',
         (('OM1_1', (1, 1)),
          ('OM1_2', (1, 1)),
          ('OM1_3', (0, -1)),
          ('OM1_4', (1, 1)),
          ('OM1_5', (1, 1)),
          ('OM1_6', (0, 1)),
          ('OM1_7', (0, 1)),
          ('OM1_8', (1, -1)),
          ('OM1_9', (0, 1)),
          ('OM1_10', (0, 1)),
          ('OM1_11', (0, 1)),
          ('OM1_12', (0, 1)),
          ('OM1_13', (0, -1)),
          ('OM1_14', (0, -1)),
          ('OM1_15', (0, 1)),
          ('OM1_16', (0, -1)),
          ('OM1_17', (0, 1)),
          ('OM1_18', (1, 1)),
          ('OM1_19', (0, 1)),
          ('OM1_20', (0, 1)),
          ('OM1_21', (0, 1)),
          ('OM1_22', (0, 1)),
          ('OM1_23', (0, 1)),
          ('OM1_24', (0, 1)),
          ('OM1_25', (0, -1)),
          ('OM1_26', (0, 1)),
          ('OM1_27', (0, -1)),
          ('OM1_28', (0, -1)),
          ('OM1_29', (0, 1)),
          ('OM1_30', (0, 1)),
          ('OM1_31', (0, 1)),
          ('OM1_32', (0, 1)),
          ('OM1_33', (0, 1)),
          ('OM1_34', (0, -1)),
          ('OM1_35', (0, 1)),
          ('OM1_36', (0, 1)),
          ('OM1_37', (0, 1)),
          ('OM1_38', (0, 1)),
          ('OM1_39', (0, 1)),
          ('OM1_40', (0, -1)),
          ('OM1_41', (0, 1)),
          ('OM1_42', (0, 1)),
          ('OM1_43', (0, 1)),
          ('OM1_44', (0, 1)),
          ('OM1_45', (0, 1)),
          ('OM1_46', (0, 1)),
          ('OM1_47', (0, 1)))),
 'OM2': ('sequence',
         (('OM2_1', (0, 1)),
          ('OM2_2', (0, 1)),
          ('OM2_3', (0, -1)),
          ('OM2_4', (0, 1)),
          ('OM2_5', (0, 1)),
          ('OM2_6', (0, -1)),
          ('OM2_7', (0, -1)),
          ('OM2_8', (0, 1)),
          ('OM2_9', (0, -1)),
          ('OM2_10', (0, 1)))),
 'OM3': ('sequence',
         (('OM3_1', (0, 1)),
          ('OM3_2', (0, 1)),
          ('OM3_3', (0, -1)),
          ('OM3_4', (0, -1)),
          ('OM3_5', (0, -1)),
          ('OM3_6', (0, -1)),
          ('OM3_7', (0, 1)))),
 'OM4': ('sequence',
         (('OM4_1', (0, 1)),
          ('OM4_2', (0, 1)),
          ('OM4_3', (0, 1)),
          ('OM4_4', (0, 1)),
          ('OM4_5', (0, 1)),
          ('OM4_6', (0, 1)),
          ('OM4_7', (0, 1)),
          ('OM4_8', (0, 1)),
          ('OM4_9', (0, 1)),
          ('OM4_10', (0, 1)),
          ('OM4_11', (0, 1)),
          ('OM4_12', (0, 1)),
          ('OM4_13', (0, -1)),
          ('OM4_14', (0, 1)))),
 'OM5': ('sequence',
         (('OM5_1', (0, 1)), ('OM5_2', (0, -1)), ('OM5_3', (0, 1)))),
 'OM6': ('sequence', (('OM6_1', (0, 1)), ('OM6_2', (0, 1)))),
 'OM7': ('sequence',
         (('OM7_1', (1, 1)),
          ('OM7_2', (1, 1)),
          ('OM7_3', (0, -1)),
          ('OM7_4', (0, 1)),
          ('OM7_5', (0, -1)),
          ('OM7_6', (0, 1)),
          ('OM7_7', (0, 1)),
          ('OM7_8', (0, 1)),
          ('OM7_9', (0, 1)),
          ('OM7_10', (0, 1)),
          ('OM7_11', (0, 1)),
          ('OM7_12', (0, 1)),
          ('OM7_13', (0, 1)),
          ('OM7_14', (0, 1)),
          ('OM7_15', (0, 1)),
          ('OM7_16', (0, 1)),
          ('OM7_17', (0, 1)),
          ('OM7_18', (0, 1)),
          ('OM7_19', (0, 1)),
          ('OM7_20', (0, 1)),
          ('OM7_21', (0, -1)),
          ('OM7_22', (0, 1)),
          ('OM7_23', (0, 1)),
          ('OM7_24', (0, -1)))),
 'ORC': ('sequence',
         (('ORC_1', (1, 1)),
          ('ORC_2', (0, 1)),
          ('ORC_3', (0, 1)),
          ('ORC_4', (0, 1)),
          ('ORC_5', (0, 1)),
          ('ORC_6', (0, 1)),
          ('ORC_7', (0, -1)),
          ('ORC_8', (0, 1)),
          ('ORC_9', (0, 1)),
          ('ORC_10', (0, -1)),
          ('ORC_11', (0, -1)),
          ('ORC_12', (0, -1)),
          ('ORC_13', (0, 1)),
          ('ORC_14', (0, 2)),
          ('ORC_15', (0, 1)),
          ('ORC_16', (0, 1)),
          ('ORC_17', (0, 1)),
          ('ORC_18', (0, 1)),
          ('ORC_19', (0, -1)),
          ('ORC_20', (0, 1)),
          ('ORC_21', (0, -1)),
          ('ORC_22', (0, -1)),
          ('ORC_23', (0, -1)),
          ('ORC_24', (0, -1)),
          ('ORC_25', (0, 1)),
          ('ORC_26', (0, 1)),
          ('ORC_27', (0, 1)),
          ('ORC_28', (0, 1)),
          ('ORC_29', (0, 1)),
          ('ORC_30', (0, 1)),
          ('ORC_31', (0, 1)))),
 'ORG': ('sequence',
         (('ORG_1', (1, 1)),
          ('ORG_2', (0, 1)),
          ('ORG_3', (0, 1)),
          ('ORG_4', (0, 1)),
          ('ORG_5', (0, 1)),
          ('ORG_6', (0, 1)),
          ('ORG_7', (0, 1)),
          ('ORG_8', (0, 1)),
          ('ORG_9', (0, 1)),
          ('ORG_10', (0, 1)),
          ('ORG_11', (0, 1)),
          ('ORG_12', (0, 1)))),
 'OVR': ('sequence',
         (('OVR_1', (0, 1)),
          ('OVR_2', (0, 1)),
          ('OVR_3', (0, 1)),
          ('OVR_4', (0, 1)),
          ('OVR_5', (0, 1)))),
 'PCE': ('sequence',
         (('PCE_1', (1, 1)),
          ('PCE_2', (0, 1)),
          ('PCE_3', (0, 1)),
          ('PCE_4', (0, 1)))),
 'PCR': ('sequence',
         (('PCR_1', (1, 1)),
          ('PCR_2', (0, 1)),
          ('PCR_3', (0, 1)),
          ('PCR_4', (0, 1)),
          ('PCR_5', (0, 1)),
          ('PCR_6', (0, 1)),
          ('PCR_7', (0, 1)),
          ('PCR_8', (0, 1)),
          ('PCR_9', (0, 1)),
          ('PCR_10', (0, 1)),
          ('PCR_11', (0, 1)),
          ('PCR_12', (0, 3)),
          ('PCR_13', (0, 1)),
          ('PCR_14', (0, 1)),
          ('PCR_15', (0, 1)),
          ('PCR_16', (0, 1)),
          ('PCR_17', (0, 1)),
          ('PCR_18', (0, 1)),
          ('PCR_19', (0, 1)),
          ('PCR_20', (0, 1)),
          ('PCR_21', (0, 6)),
          ('PCR_22', (0, 6)),
          ('PCR_23', (0, 3)))),
 'PD1': ('sequence',
         (('PD1_1', (0, -1)),
          ('PD1_2', (0, 1)),
          ('PD1_3', (0, -1)),
          ('PD1_4', (0, -1)),
          ('PD1_5', (0, 1)),
          ('PD1_6', (0, 1)),
          ('PD1_7', (0, 1)),
          ('PD1_8', (0, 1)),
          ('PD1_9', (0, 1)),
          ('PD1_10', (0, -1)),
          ('PD1_11', (0, 1)),
          ('PD1_12', (0, 1)),
          ('PD1_13', (0, 1)),
          ('PD1_14', (0, -1)),
          ('PD1_15', (0, -1)),
          ('PD1_16', (0, 1)),
          ('PD1_17', (0, 1)),
          ('PD1_18', (0, 1)),
          ('PD1_19', (0, 1)),
          ('PD1_20', (0, 1)),
          ('PD1_21', (0, 1)),
          ('PD1_22', (0, 1)))),
 'PDA': ('sequence',
         (('PDA_1', (0, -1)),
          ('PDA_2', (0, 1)),
          ('PDA_3', (0, 1)),
          ('PDA_4', (0, 1)),
          ('PDA_5', (0, 1)),
          ('PDA_6', (0, 1)),
          ('PDA_7', (0, 1)),
          ('PDA_8', (0, 1)),
          ('PDA_9', (0, 1)))),
 'PDC': ('sequence',
         (('PDC_1', (1, -1)),
          ('PDC_2', (1, 1)),
          ('PDC_3', (1, 1)),
          ('PDC_4', (0, 1)),
          ('PDC_5', (0, 1)),
          ('PDC_6', (0, -1)),
          ('PDC_7', (0, 1)),
          ('PDC_8', (0, -1)),
          ('PDC_9', (0, 1)),
          ('PDC_10', (0, 1)),
          ('PDC_11', (0, 1)),
          ('PDC_12', (0, 1)),
          ('PDC_13', (0, 1)),
          ('PDC_14', (0, 1)),
          ('PDC_15', (0, 1)))),
 'PEO': ('sequence',
         (('PEO_1', (0, -1)),
          ('PEO_2', (0, -1)),
          ('PEO_3', (1, 1)),
          ('PEO_4', (0, 1)),
          ('PEO_5', (0, 1)),
          ('PEO_6', (0, 1)),
          ('PEO_7', (0, -1)),
          ('PEO_8', (0, -1)),
          ('PEO_9', (0, 1)),
          ('PEO_10', (0, 1)),
          ('PEO_11', (0, -1)),
          ('PEO_12', (0, 1)),
          ('PEO_13', (0, -1)),
          ('PEO_14', (0, -1)),
          ('PEO_15', (0, -1)),
          ('PEO_16', (0, -1)),
          ('PEO_17', (0, -1)),
          ('PEO_18', (0, -1)),
          ('PEO_19', (0, -1)),
          ('PEO_20', (0, -1)),
          ('PEO_21', (0, -1)),
          ('PEO_22', (0, 1)),
          ('PEO_23', (0, 1)),
          ('PEO_24', (0, 1)),
          ('PEO_25', (0, 1)))),
 'PES': ('sequence',
         (('PES_1', (0, -1)),
          ('PES_2', (0, -1)),
          ('PES_3', (0, -1)),
          ('PES_4', (0, -1)),
          ('PES_5', (0, 1)),
          ('PES_6', (0, 1)),
          ('PES_7', (0, -1)),
          ('PES_8', (0, 1)),
          ('PES_9', (0, 1)),
          ('PES_10', (1, 1)),
          ('PES_11', (0, 2)),
          ('PES_12', (0, 1)),
          ('PES_13', (0, -1)))),
 'PID': ('sequence',
         (('PID_1', (0, 1)),
          ('PID_2', (0, 1)),
          ('PID_3', (1, -1)),
          ('PID_4', (0, -1)),
          ('PID_5', (1, -1)),
          ('PID_6', (0, -1)),
          ('PID_7', (0, 1)),
          ('PID_8', (0, 1)),
          ('PID_9', (0, -1)),
          ('PID_10', (0, -1)),
          ('PID_11', (0, -1)),
          ('PID_12', (0, 1)),
          ('PID_13', (0, -1)),
          ('PID_14', (0, -1)),
          ('PID_15', (0, 1)),
          ('PID_16', (0, 1)),
          ('PID_17', (0, 1)),
          ('PID_18', (0, 1)),
          ('PID_19', (0, 1)),
          ('PID_20', (0, 1)),
          ('PID_21', (0, -1)),
          ('PID_22', (0, -1)),
          ('PID_23', (0, 1)),
          ('PID_24', (0, 1)),
          ('PID_25', (0, 1)),
          ('PID_26', (0, -1)),
          ('PID_27', (0, 1)),
          ('PID_28', (0, 1)),
          ('PID_29', (0, 1)),
          ('PID_30', (0, 1)),
          ('PID_31', (0, 1)),
          ('PID_32', (0, -1)),
          ('PID_33', (0, 1)),
          ('PID_34', (0, 1)),
          ('PID_35', (0, 1)),
          ('PID_36', (0, 1)),
          ('PID_37', (0, 1)),
          ('PID_38', (0, -1)),
          ('PID_39', (0, -1)))),
 'PKG': ('sequence',
         (('PKG_1', (1, 1)),
          ('PKG_2', (0, 1)),
          ('PKG_3', (0, 1)),
          ('PKG_4', (0, 1)),
          ('PKG_5', (0, 1)),
          ('PKG_6', (0, 1)),
          ('PKG_7', (0, 1)))),
 'PMT': ('sequence',
         (('PMT_1', (1, 1)),
          ('PMT_2', (1, 1)),
          ('PMT_3', (1, 1)),
          ('PMT_4', (1, 1)),
          ('PMT_5', (1, 1)),
          ('PMT_6', (1, 1)),
          ('PMT_7', (0, 1)),
          ('PMT_8', (0, 1)),
          ('PMT_9', (0, 1)),
          ('PMT_10', (0, 1)),
          ('PMT_11', (1, 1)),
          ('PMT_12', (0, 1)))),
 'PR1': ('sequence',
         (('PR1_1', (1, 1)),
          ('PR1_3', (1, 1)),
          ('PR1_5', (1, 1)),
          ('PR1_6', (0, 1)),
          ('PR1_7', (0, 1)),
          ('PR1_9', (0, 1)),
          ('PR1_10', (0, 1)),
          ('PR1_13', (0, 1)),
          ('PR1_14', (0, 1)),
          ('PR1_15', (0, 1)),
          ('PR1_16', (0, -1)),
          ('PR1_17', (0, 1)),
          ('PR1_18', (0, -1)),
          ('PR1_19', (0, 1)),
          ('PR1_20', (0, 1)),
          ('PR1_21', (0, 1)),
          ('PR1_22', (0, 1)))),
 'PRA': ('sequence',
         (('PRA_1', (0, 1)),
          ('PRA_2', (0, -1)),
          ('PRA_3', (0, -1)),
          ('PRA_4', (0, 1)),
          ('PRA_5', (0, -1)),
          ('PRA_6', (0, -1)),
          ('PRA_7', (0, -1)),
          ('PRA_8', (0, 1)),
          ('PRA_9', (0, 1)),
          ('PRA_10', (0, 1)),
          ('PRA_11', (0, -1)),
          ('PRA_12', (0, 1)))),
 'PRB': ('sequence',
         (('PRB_1', (1, 1)),
          ('PRB_2', (1, 1)),
          ('PRB_3', (1, 1)),
          ('PRB_4', (1, 1)),
          ('PRB_5', (0, 1)),
          ('PRB_6', (0, 1)),
          ('PRB_7', (0, 1)),
          ('PRB_8', (0, 1)),
          ('PRB_9', (0, 1)),
          ('PRB_10', (0, 1)),
          ('PRB_11', (0, -1)),
          ('PRB_12', (0, 1)),
          ('PRB_13', (0, 1)),
          ('PRB_14', (0, 1)),
          ('PRB_15', (0, 1)),
          ('PRB_16', (0, 1)),
          ('PRB_17', (0, 1)),
          ('PRB_18', (0, 1)),
          ('PRB_19', (0, 1)),
          ('PRB_20', (0, 1)),
          ('PRB_21', (0, 1)),
          ('PRB_22', (0, 1)),
          ('PRB_23', (0, 1)),
          ('PRB_24', (0, 1)),
          ('PRB_25', (0, 1)),
          ('PRB_26', (0, 1)),
          ('PRB_27', (0, 1)),
          ('PRB_28', (0, 1)))),
 'PRC': ('sequence',
         (('PRC_1', (1, 1)),
          ('PRC_2', (0, -1)),
          ('PRC_3', (0, -1)),
          ('PRC_4', (0, -1)),
          ('PRC_5', (0, -1)),
          ('PRC_6', (0, -1)),
          ('PRC_7', (0, 1)),
          ('PRC_8', (0, 1)),
          ('PRC_9', (0, 1)),
          ('PRC_10', (0, 1)),
          ('PRC_11', (0, 1)),
          ('PRC_12', (0, 1)),
          ('PRC_13', (0, 1)),
          ('PRC_14', (0, -1)),
          ('PRC_15', (0, 1)),
          ('PRC_16', (0, 1)),
          ('PRC_17', (0, 1)),
          ('PRC_18', (0, 1)))),
 'PRD': ('sequence',
         (('PRD_1', (1, -1)),
          ('PRD_2', (0, -1)),
          ('PRD_3', (0, -1)),
          ('PRD_4', (0, 1)),
          ('PRD_5', (0, -1)),
          ('PRD_6', (0, 1)),
          ('PRD_7', (0, -1)),
          ('PRD_8', (0, 1)),
          ('PRD_9', (0, -1)),
          ('PRD_10', (0, -1)),
          ('PRD_11', (0, -1)),
          ('PRD_12', (0, -1)),
          ('PRD_13', (0, -1)),
          ('PRD_14', (0, -1)))),
 'PSG': ('sequence',
         (('PSG_1', (1, 1)),
          ('PSG_2', (0, 1)),
          ('PSG_3', (1, 1)),
          ('PSG_4', (1, 1)),
          ('PSG_5', (1, 1)),
          ('PSG_6', (1, 1)))),
 'PSH': ('sequence',
         (('PSH_1', (1, 1)),
          ('PSH_2', (0, 1)),
          ('PSH_3', (1, 1)),
          ('PSH_4', (0, 1)),
          ('PSH_5', (0, 1)),
          ('PSH_6', (0, 1)),
          ('PSH_7', (0, 1)),
          ('PSH_8', (0, 1)),
          ('PSH_9', (0, 1)),
          ('PSH_10', (0, 1)),
          ('PSH_11', (0, 1)),
          ('PSH_12', (0, 1)),
          ('PSH_13', (0, 8)),
          ('PSH_14', (0, 8)))),
 'PSL': ('sequence',
         (('PSL_1', (1, 1)),
          ('PSL_2', (0, 1)),
          ('PSL_3', (1, 1)),
          ('PSL_4', (0, 1)),
          ('PSL_5', (0, 1)),
          ('PSL_6', (1, 1)),
          ('PSL_7', (1, 1)),
          ('PSL_8', (0, -1)),
          ('PSL_9', (0, 1)),
          ('PSL_10', (0, 1)),
          ('PSL_11', (0, 1)),
          ('PSL_12', (0, 1)),
          ('PSL_13', (0, 1)),
          ('PSL_14', (0, 1)),
          ('PSL_15', (0, 1)),
          ('PSL_16', (0, 1)),
          ('PSL_17', (0, -1)),
          ('PSL_18', (0, -1)),
          ('PSL_19', (0, -1)),
          ('PSL_20', (0, -1)),
          ('PSL_21', (1, 1)),
          ('PSL_22', (0, 1)),
          ('PSL_23', (0, 1)),
          ('PSL_24', (0, 1)),
          ('PSL_25', (0, 1)),
          ('PSL_26', (0, 1)),
          ('PSL_27', (0, 1)),
          ('PSL_28', (0, 1)),
          ('PSL_29', (0, 1)),
          ('PSL_30', (0, 1)),
          ('PSL_31', (0, 1)),
          ('PSL_32', (0, 1)),
          ('PSL_33', (0, 1)),
          ('PSL_34', (0, 1)),
          ('PSL_35', (0, 1)),
          ('PSL_36', (0, 1)),
          ('PSL_37', (0, 1)),
          ('PSL_38', (0, 1)),
          ('PSL_39', (0, 1)),
          ('PSL_40', (0, 1)),
          ('PSL_41', (0, 1)),
          ('PSL_42', (0, 1)),
          ('PSL_43', (0, 1)),
          ('PSL_44', (0, 1)),
          ('PSL_45', (0, 1)),
          ('PSL_46', (0, 1)),
          ('PSL_47', (0, 1)),
          ('PSL_48', (0, 1)))),
 'PSS': ('sequence',
         (('PSS_1', (1, 1)),
          ('PSS_2', (0, 1)),
          ('PSS_3', (1, 1)),
          ('PSS_4', (1, 1)),
          ('PSS_5', (1, 1)))),
 'PTH': ('sequence',
         (('PTH_1', (1, 1)),
          ('PTH_2', (1, 1)),
          ('PTH_3', (1, 1)),
          ('PTH_4', (1, 1)),
          ('PTH_5', (0, 1)),
          ('PTH_6', (0, 1)),
          ('PTH_7', (0, 1)))),
 'PV1': ('sequence',
         (('PV1_1', (0, 1)),
          ('PV1_2', (1, 1)),
          ('PV1_3', (0, 1)),
          ('PV1_4', (0, 1)),
          ('PV1_5', (0, 1)),
          ('PV1_6', (0, 1)),
          ('PV1_7', (0, -1)),
          ('PV1_8', (0, -1)),
          ('PV1_9', (0, -1)),
          ('PV1_10', (0, 1)),
          ('PV1_11', (0, 1)),
          ('PV1_12', (0, 1)),
          ('PV1_13', (0, 1)),
          ('PV1_14', (0, 1)),
          ('PV1_15', (0, -1)),
          ('PV1_16', (0, 1)),
          ('PV1_17', (0, -1)),
          ('PV1_18', (0, 1)),
          ('PV1_19', (0, 1)),
          ('PV1_20', (0, -1)),
          ('PV1_21', (0, 1)),
          ('PV1_22', (0, 1)),
          ('PV1_23', (0, 1)),
          ('PV1_24', (0, -1)),
          ('PV1_25', (0, -1)),
          ('PV1_26', (0, -1)),
          ('PV1_27', (0, -1)),
          ('PV1_28', (0, 1)),
          ('PV1_29', (0, 1)),
          ('PV1_30', (0, 1)),
          ('PV1_31', (0, 1)),
          ('PV1_32', (0, 1)),
          ('PV1_33', (0, 1)),
          ('PV1_34', (0, 1)),
          ('PV1_35', (0, 1)),
          ('PV1_36', (0, 1)),
          ('PV1_37', (0, 1)),
          ('PV1_38', (0, 1)),
          ('PV1_39', (0, 1)),
          ('PV1_40', (0, 1)),
          ('PV1_41', (0, 1)),
          ('PV1_42', (0, 1)),
          ('PV1_43', (0, 1)),
          ('PV1_44', (0, 1)),
          ('PV1_45', (0, 1)),
          ('PV1_46', (0, 1)),
          ('PV1_47', (0, 1)),
          ('PV1_48', (0, 1)),
          ('PV1_49', (0, 1)),
          ('PV1_50', (0, 1)),
          ('PV1_51', (0, 1)),
          ('PV1_52', (0, -1)))),
 'PV2': ('sequence',
         (('PV2_1', (0, 1)),
          ('PV2_2', (0, 1)),
          ('PV2_3', (0, 1)),
          ('PV2_4', (0, 1)),
          ('PV2_5', (0, -1)),
          ('PV2_6', (0, 1)),
          ('PV2_7', (0, -1)),
          ('PV2_8', (0, 1)),
          ('PV2_9', (0, 1)),
          ('PV2_10', (0, 1)),
          ('PV2_11', (0, 1)),
          ('PV2_12', (0, 1)),
          ('PV2_13', (0, -1)),
          ('PV2_14', (0, 1)),
          ('PV2_15', (0, 1)),
          ('PV2_16', (0, 1)),
          ('PV2_17', (0, 1)),
          ('PV2_18', (0, 1)),
          ('PV2_19', (0, 1)),
          ('PV2_20', (0, 1)),
          ('PV2_21', (0, 1)),
          ('PV2_22', (0, 1)),
          ('PV2_23', (0, -1)),
          ('PV2_24', (0, 1)),
          ('PV2_25', (0, 1)),
          ('PV2_26', (0, 1)),
          ('PV2_27', (0, 1)),
          ('PV2_28', (0, 1)),
          ('PV2_29', (0, 1)),
          ('PV2_30', (0, 1)),
          ('PV2_31', (0, 1)),
          ('PV2_32', (0, 1)),
          ('PV2_33', (0, 1)),
          ('PV2_34', (0, 1)),
          ('PV2_35', (0, 1)),
          ('PV2_36', (0, 1)),
          ('PV2_37', (0, 1)),
          ('PV2_38', (0, 1)),
          ('PV2_39', (0, -1)),
          ('PV2_40', (0, 1)),
          ('PV2_41', (0, -1)),
          ('PV2_42', (0, 1)),
          ('PV2_43', (0, 1)),
          ('PV2_44', (0, 1)),
          ('PV2_45', (0, -1)),
          ('PV2_46', (0, 1)),
          ('PV2_47', (0, 1)),
          ('PV2_48', (0, 1)),
          ('PV2_49', (0, -1)),
          ('PV2_50', (0, 1)))),
 'PYE': ('sequence',
         (('PYE_1', (1, 1)),
          ('PYE_2', (1, 1)),
          ('PYE_3', (0, 1)),
          ('PYE_4', (0, -1)),
          ('PYE_5', (0, -1)),
          ('PYE_6', (0, -1)),
          ('PYE_7', (0, 1)))),
 'QAK': ('sequence',
         (('QAK_1', (0, 1)),
          ('QAK_2', (0, 1)),
          ('QAK_3', (0, 1)),
          ('QAK_4', (0, 1)),
          ('QAK_5', (0, 1)),
          ('QAK_6', (0, 1)))),
 'QID': ('sequence', (('QID_1', (1, 1)), ('QID_2', (1, 1)))),
 'QPD': ('sequence',
         (('QPD_1', (1, 1)), ('QPD_2', (0, 1)), ('QPD_3', (0, 1)))),
 'QRD': ('sequence',
         (('QRD_1', (1, 1)),
          ('QRD_2', (1, 1)),
          ('QRD_3', (1, 1)),
          ('QRD_4', (1, 1)),
          ('QRD_5', (0, 1)),
          ('QRD_6', (0, 1)),
          ('QRD_7', (1, 1)),
          ('QRD_8', (1, -1)),
          ('QRD_9', (1, -1)),
          ('QRD_10', (1, -1)),
          ('QRD_11', (0, -1)),
          ('QRD_12', (0, 1)))),
 'QRF': ('sequence',
         (('QRF_1', (1, -1)),
          ('QRF_2', (0, 1)),
          ('QRF_3', (0, 1)),
          ('QRF_4', (0, -1)),
          ('QRF_5', (0, -1)),
          ('QRF_6', (0, -1)),
          ('QRF_7', (0, -1)),
          ('QRF_8', (0, -1)),
          ('QRF_9', (0, 1)),
          ('QRF_10', (0, 1)))),
 'QRI': ('sequence',
         (('QRI_1', (0, 1)), ('QRI_2', (0, -1)), ('QRI_3', (0, 1)))),
 'RCP': ('sequence',
         (('RCP_1', (0, 1)),
          ('RCP_2', (0, 1)),
          ('RCP_3', (0, 1)),
          ('RCP_4', (0, 1)),
          ('RCP_5', (0, 1)),
          ('RCP_6', (0, -1)),
          ('RCP_7', (0, -1)))),
 'RDF': ('sequence', (('RDF_1', (1, 1)), ('RDF_2', (1, -1)))),
 'RDT': ('sequence', (('RDT_1', (1, 1)),)),
 'REL': ('sequence',
         (('REL_1', (0, 1)),
          ('REL_2', (1, 1)),
          ('REL_3', (1, 1)),
          ('REL_4', (1, 1)),
          ('REL_5', (1, 1)),
          ('REL_6', (0, 1)),
          ('REL_7', (0, 1)),
          ('REL_8', (0, 1)),
          ('REL_9', (0, 1)),
          ('REL_10', (0, 1)),
          ('REL_11', (0, 1)),
          ('REL_12', (0, 1)),
          ('REL_13', (0, 1)),
          ('REL_14', (0, 1)),
          ('REL_15', (0, 1)),
          ('REL_16', (0, 1)))),
 'RF1': ('sequence',
         (('RF1_1', (0, 1)),
          ('RF1_2', (0, 1)),
          ('RF1_3', (0, 1)),
          ('RF1_4', (0, -1)),
          ('RF1_5', (0, 1)),
          ('RF1_6', (1, 1)),
          ('RF1_7', (0, 1)),
          ('RF1_8', (0, 1)),
          ('RF1_9', (0, 1)),
          ('RF1_10', (0, -1)),
          ('RF1_11', (0, -1)),
          ('RF1_12', (0, 1)))),
 'RFI': ('sequence',
         (('RFI_1', (1, 1)),
          ('RFI_2', (1, 1)),
          ('RFI_3', (0, 1)),
          ('RFI_4', (0, 1)))),
 'RGS': ('sequence',
         (('RGS_1', (1, 1)), ('RGS_2', (0, 1)), ('RGS_3', (0, 1)))),
 'RMI': ('sequence',
         (('RMI_1', (0, 1)), ('RMI_2', (0, 1)), ('RMI_3', (0, 1)))),
 'ROL': ('sequence',
         (('ROL_1', (0, 1)),
          ('ROL_2', (1, 1)),
          ('ROL_3', (1, 1)),
          ('ROL_4', (1, -1)),
          ('ROL_5', (0, 1)),
          ('ROL_6', (0, 1)),
          ('ROL_7', (0, 1)),
          ('ROL_8', (0, 1)),
          ('ROL_9', (0, -1)),
          ('ROL_10', (0, 1)),
          ('ROL_11', (0, -1)),
          ('ROL_12', (0, -1)),
          ('ROL_13', (0, 1)))),
 'RQ1': ('sequence',
         (('RQ1_1', (0, 1)),
          ('RQ1_2', (0, 1)),
          ('RQ1_3', (0, 1)),
          ('RQ1_4', (0, 1)),
          ('RQ1_5', (0, 1)),
          ('RQ1_6', (0, 1)),
          ('RQ1_7', (0, 1)))),
 'RQD': ('sequence',
         (('RQD_1', (0, 1)),
          ('RQD_2', (0, 1)),
          ('RQD_3', (0, 1)),
          ('RQD_4', (0, 1)),
          ('RQD_5', (0, 1)),
          ('RQD_6', (0, 1)),
          ('RQD_7', (0, 1)),
          ('RQD_8', (0, 1)),
          ('RQD_9', (0, 1)),
          ('RQD_10', (0, 1)))),
 'RXA': ('sequence',
         (('RXA_1', (1, 1)),
          ('RXA_2', (1, 1)),
          ('RXA_3', (1, 1)),
          ('RXA_4', (1, 1)),
          ('RXA_5', (1, 1)),
          ('RXA_6', (1, 1)),
          ('RXA_7', (0, 1)),
          ('RXA_8', (0, 1)),
          ('RXA_9', (0, -1)),
          ('RXA_10', (0, -1)),
          ('RXA_11', (0, 1)),
          ('RXA_12', (0, 1)),
          ('RXA_13', (0, 1)),
          ('RXA_14', (0, 1)),
          ('RXA_15', (0, -1)),
          ('RXA_16', (0, -1)),
          ('RXA_17', (0, -1)),
          ('RXA_18', (0, -1)),
          ('RXA_19', (0, -1)),
          ('RXA_20', (0, 1)),
          ('RXA_21', (0, 1)),
          ('RXA_22', (0, 1)),
          ('RXA_23', (0, 1)),
          ('RXA_24', (0, 1)),
          ('RXA_25', (0, 1)),
          ('RXA_26', (0, 1)),
          ('RXA_27', (0, 1)),
          ('RXA_28', (0, 1)))),
 'RXC': ('sequence',
         (('RXC_1', (1, 1)),
          ('RXC_2', (1, 1)),
          ('RXC_3', (1, 1)),
          ('RXC_4', (1, 1)),
          ('RXC_5', (0, 1)),
          ('RXC_6', (0, 1)),
          ('RXC_7', (0, -1)),
          ('RXC_8', (0, 1)),
          ('RXC_9', (0, 1)))),
 'RXD': ('sequence',
         (('RXD_1', (1, 1)),
          ('RXD_2', (1, 1)),
          ('RXD_3', (1, 1)),
          ('RXD_4', (1, 1)),
          ('RXD_5', (0, 1)),
          ('RXD_6', (0, 1)),
          ('RXD_7', (1, 1)),
          ('RXD_8', (0, 1)),
          ('RXD_9', (0, -1)),
          ('RXD_10', (0, -1)),
          ('RXD_11', (0, 1)),
          ('RXD_12', (0, 1)),
          ('RXD_13', (0, 1)),
          ('RXD_14', (0, 1)),
          ('RXD_15', (0, -1)),
          ('RXD_16', (0, 1)),
          ('RXD_17', (0, 1)),
          ('RXD_18', (0, -1)),
          ('RXD_19', (0, -1)),
          ('RXD_20', (0, -1)),
          ('RXD_21', (0, -1)),
          ('RXD_22', (0, 1)),
          ('RXD_23', (0, 1)),
          ('RXD_24', (0, 1)),
          ('RXD_25', (0, -1)),
          ('RXD_26', (0, 1)),
          ('RXD_27', (0, 1)),
          ('RXD_28', (0, 1)),
          ('RXD_29', (0, 1)),
          ('RXD_30', (0, 1)),
          ('RXD_31', (0, 1)),
          ('RXD_32', (0, 1)),
          ('RXD_33', (0, 1)))),
 'RXE': ('sequence',
         (('RXE_1', (0, 1)),
          ('RXE_2', (1, 1)),
          ('RXE_3', (1, 1)),
          ('RXE_4', (0, 1)),
          ('RXE_5', (1, 1)),
          ('RXE_6', (0, 1)),
          ('RXE_7', (0, -1)),
          ('RXE_8', (0, 1)),
          ('RXE_9', (0, 1)),
          ('RXE_10', (0, 1)),
          ('RXE_11', (0, 1)),
          ('RXE_12', (0, 1)),
          ('RXE_13', (0, -1)),
          ('RXE_14', (0, -1)),
          ('RXE_15', (0, 1)),
          ('RXE_16', (0, 1)),
          ('RXE_17', (0, 1)),
          ('RXE_18', (0, 1)),
          ('RXE_19', (0, 1)),
          ('RXE_20', (0, 1)),
          ('RXE_21', (0, -1)),
          ('RXE_22', (0, 1)),
          ('RXE_23', (0, 1)),
          ('RXE_24', (0, 1)),
          ('RXE_25', (0, 1)),
          ('RXE_26', (0, 1)),
          ('RXE_27', (0, -1)),
          ('RXE_28', (0, 1)),
          ('RXE_29', (0, 1)),
          ('RXE_30', (0, 1)),
          ('RXE_31', (0, -1)),
          ('RXE_32', (0, 1)),
          ('RXE_33', (0, 1)),
          ('RXE_34', (0, 1)),
          ('RXE_35', (0, 1)),
          ('RXE_36', (0, 1)),
          ('RXE_37', (0, -1)),
          ('RXE_38', (0, 1)),
          ('RXE_39', (0, 1)),
          ('RXE_40', (0, 1)),
          ('RXE_41', (0, 1)),
          ('RXE_42', (0, 1)),
          ('RXE_43', (0, 1)),
          ('RXE_44', (0, 1)))),
 'RXG': ('sequence',
         (('RXG_1', (1, 1)),
          ('RXG_2', (0, 1)),
          ('RXG_3', (0, 1)),
          ('RXG_4', (1, 1)),
          ('RXG_5', (1, 1)),
          ('RXG_6', (0, 1)),
          ('RXG_7', (1, 1)),
          ('RXG_8', (0, 1)),
          ('RXG_9', (0, -1)),
          ('RXG_10', (0, 1)),
          ('RXG_11', (0, 1)),
          ('RXG_12', (0, 1)),
          ('RXG_13', (0, -1)),
          ('RXG_14', (0, 1)),
          ('RXG_15', (0, 1)),
          ('RXG_16', (0, 1)),
          ('RXG_17', (0, 1)),
          ('RXG_18', (0, 1)),
          ('RXG_19', (0, -1)),
          ('RXG_20', (0, -1)),
          ('RXG_21', (0, -1)),
          ('RXG_22', (0, -1)),
          ('RXG_23', (0, 1)),
          ('RXG_24', (0, 1)),
          ('RXG_25', (0, 1)),
          ('RXG_26', (0, 1)),
          ('RXG_27', (0, 1)),
          ('RXG_28', (0, 1)),
          ('RXG_29', (0, 1)),
          ('RXG_30', (0, 1)))),
 'RXO': ('sequence',
         (('RXO_1', (0, 1)),
          ('RXO_2', (0, 1)),
          ('RXO_3', (0, 1)),
          ('RXO_4', (0, 1)),
          ('RXO_5', (0, 1)),
          ('RXO_6', (0, -1)),
          ('RXO_7', (0, -1)),
          ('RXO_8', (0, 1)),
          ('RXO_9', (0, 1)),
          ('RXO_10', (0, 1)),
          ('RXO_11', (0, 1)),
          ('RXO_12', (0, 1)),
          ('RXO_13', (0, 1)),
          ('RXO_14', (0, -1)),
          ('RXO_15', (0, -1)),
          ('RXO_16', (0, 1)),
          ('RXO_17', (0, 1)),
          ('RXO_18', (0, 1)),
          ('RXO_19', (0, 1)),
          ('RXO_20', (0, -1)),
          ('RXO_21', (0, 1)),
          ('RXO_22', (0, 1)),
          ('RXO_23', (0, 1)),
          ('RXO_24', (0, -1)),
          ('RXO_25', (0, 1)),
          ('RXO_26', (0, 1)),
          ('RXO_27', (0, 1)),
          ('RXO_28', (0, 1)),
          ('RXO_29', (0, 1)),
          ('RXO_30', (0, 1)),
          ('RXO_31', (0, 1)),
          ('RXO_32', (0, 1)),
          ('RXO_33', (0, 1)),
          ('RXO_34', (0, 1)),
          ('RXO_35', (0, 1)))),
 'RXR': ('sequence',
         (('RXR_1', (1, 1)),
          ('RXR_2', (0, 1)),
          ('RXR_3', (0, 1)),
          ('RXR_4', (0, 1)),
          ('RXR_5', (0, 1)),
          ('RXR_6', (0, 1)))),
 'SAC': ('sequence',
         (('SAC_1', (0, 1)),
          ('SAC_2', (0, 1)),
          ('SAC_3', (0, 1)),
          ('SAC_4', (0, 1)),
          ('SAC_5', (0, 1)),
          ('SAC_6', (0, 1)),
          ('SAC_7', (0, 1)),
          ('SAC_8', (0, 1)),
          ('SAC_9', (0, 1)),
          ('SAC_10', (0, 1)),
          ('SAC_11', (0, 1)),
          ('SAC_12', (0, 1)),
          ('SAC_13', (0, 1)),
          ('SAC_14', (0, 1)),
          ('SAC_15', (0, -1)),
          ('SAC_16', (0, 1)),
          ('SAC_17', (0, 1)),
          ('SAC_18', (0, 1)),
          ('SAC_19', (0, 1)),
          ('SAC_20', (0, 1)),
          ('SAC_21', (0, 1)),
          ('SAC_22', (0, 1)),
          ('SAC_23', (0, 1)),
          ('SAC_24', (0, 1)),
          ('SAC_25', (0, 1)),
          ('SAC_26', (0, 1)),
          ('SAC_27', (0, -1)),
          ('SAC_28', (0, 1)),
          ('SAC_29', (0, 1)),
          ('SAC_30', (0, 1)),
          ('SAC_31', (0, 1)),
          ('SAC_32', (0, 1)),
          ('SAC_33', (0, 1)),
          ('SAC_34', (0, 1)),
          ('SAC_35', (0, 1)),
          ('SAC_36', (0, 1)),
          ('SAC_37', (0, 1)),
          ('SAC_38', (0, 1)),
          ('SAC_39', (0, 1)),
          ('SAC_40', (0, -1)),
          ('SAC_41', (0, -1)),
          ('SAC_42', (0, 1)),
          ('SAC_43', (0, -1)),
          ('SAC_44', (0, -1)))),
 'SCD': ('sequence',
         (('SCD_1', (0, 1)),
          ('SCD_2', (0, 1)),
          ('SCD_3', (0, 1)),
          ('SCD_4', (0, 1)),
          ('SCD_5', (0, 1)),
          ('SCD_6', (0, 1)),
          ('SCD_7', (0, 1)),
          ('SCD_8', (0, 1)),
          ('SCD_9', (0, 1)),
          ('SCD_10', (0, 1)),
          ('SCD_11', (0, 1)),
          ('SCD_12', (0, 1)),
          ('SCD_13', (0, 1)),
          ('SCD_14', (0, 1)),
          ('SCD_15', (0, 1)),
          ('SCD_16', (0, 1)),
          ('SCD_17', (0, 1)),
          ('SCD_18', (0, 1)),
          ('SCD_19', (0, 1)),
          ('SCD_20', (0, 1)),
          ('SCD_21', (0, 1)),
          ('SCD_22', (0, 1)),
          ('SCD_23', (0, 1)),
          ('SCD_24', (0, 1)),
          ('SCD_25', (0, 1)),
          ('SCD_26', (0, 1)),
          ('SCD_27', (0, 1)),
          ('SCD_28', (0, 1)),
          ('SCD_29', (0, 1)),
          ('SCD_30', (0, 1)),
          ('SCD_31', (0, 1)),
          ('SCD_32', (0, 1)),
          ('SCD_33', (0, -1)),
          ('SCD_34', (0, 1)),
          ('SCD_35', (0, 1)),
          ('SCD_36', (0, 1)),
          ('SCD_37', (0, 1)))),
 'SCH': ('sequence',
         (('SCH_1', (0, 1)),
          ('SCH_2', (0, 1)),
          ('SCH_3', (0, 1)),
          ('SCH_4', (0, 1)),
          ('SCH_5', (0, 1)),
          ('SCH_6', (1, 1)),
          ('SCH_7', (0, 1)),
          ('SCH_8', (0, 1)),
          ('SCH_9', (0, 1)),
          ('SCH_10', (0, 1)),
          ('SCH_11', (0, -1)),
          ('SCH_12', (0, -1)),
          ('SCH_13', (0, 1)),
          ('SCH_14', (0, -1)),
          ('SCH_15', (0, 1)),
          ('SCH_16', (1, -1)),
          ('SCH_17', (0, 1)),
          ('SCH_18', (0, -1)),
          ('SCH_19', (0, 1)),
          ('SCH_20', (1, -1)),
          ('SCH_21', (0, -1)),
          ('SCH_22', (0, 1)),
          ('SCH_23', (0, 1)),
          ('SCH_24', (0, 1)),
          ('SCH_25', (0, 1)),
          ('SCH_26', (0, -1)),
          ('SCH_27', (0, -1)))),
 'SCP': ('sequence',
         (('SCP_1', (0, 1)),
          ('SCP_2', (0, 1)),
          ('SCP_3', (0, 1)),
          ('SCP_4', (0, 1)),
          ('SCP_5', (0, 1)),
          ('SCP_6', (0, 1)),
          ('SCP_7', (0, 1)),
          ('SCP_8', (0, 1)))),
 'SDD': ('sequence',
         (('SDD_1', (0, 1)),
          ('SDD_2', (0, 1)),
          ('SDD_3', (0, 1)),
          ('SDD_4', (0, 1)),
          ('SDD_5', (0, 1)),
          ('SDD_6', (0, 1)),
          ('SDD_7', (0, 1)))),
 'SFT': ('sequence',
         (('SFT_1', (1, 1)),
          ('SFT_2', (1, 1)),
          ('SFT_3', (1, 1)),
          ('SFT_4', (1, 1)),
          ('SFT_5', (0, 1)),
          ('SFT_6', (0, 1)))),
 'SID': ('sequence',
         (('SID_1', (0, 1)),
          ('SID_2', (0, 1)),
          ('SID_3', (0, 1)),
          ('SID_4', (0, 1)))),
 'SLT': ('sequence',
         (('SLT_1', (0, 1)),
          ('SLT_2', (0, 1)),
          ('SLT_3', (0, 1)),
          ('SLT_4', (0, 1)),
          ('SLT_5', (0, 1)))),
 'SPM': ('sequence',
         (('SPM_1', (0, 1)),
          ('SPM_2', (0, 1)),
          ('SPM_3', (0, -1)),
          ('SPM_4', (1, 1)),
          ('SPM_5', (0, -1)),
          ('SPM_6', (0, -1)),
          ('SPM_7', (0, 1)),
          ('SPM_8', (0, 1)),
          ('SPM_9', (0, -1)),
          ('SPM_10', (0, 1)),
          ('SPM_11', (0, -1)),
          ('SPM_12', (0, 1)),
          ('SPM_13', (0, 1)),
          ('SPM_14', (0, -1)),
          ('SPM_15', (0, -1)),
          ('SPM_16', (0, -1)),
          ('SPM_17', (0, 1)),
          ('SPM_18', (0, 1)),
          ('SPM_19', (0, 1)),
          ('SPM_20', (0, 1)),
          ('SPM_21', (0, -1)),
          ('SPM_22', (0, 1)),
          ('SPM_23', (0, 1)),
          ('SPM_24', (0, -1)),
          ('SPM_25', (0, 1)),
          ('SPM_26', (0, 1)),
          ('SPM_27', (0, 1)),
          ('SPM_28', (0, 1)),
          ('SPM_29', (0, 1)))),
 'STF': ('sequence',
         (('STF_1', (0, 1)),
          ('STF_2', (0, -1)),
          ('STF_3', (0, -1)),
          ('STF_4', (0, -1)),
          ('STF_5', (0, 1)),
          ('STF_6', (0, 1)),
          ('STF_7', (0, 1)),
          ('STF_8', (0, -1)),
          ('STF_9', (0, -1)),
          ('STF_10', (0, -1)),
          ('STF_11', (0, -1)),
          ('STF_12', (0, -1)),
          ('STF_13', (0, -1)),
          ('STF_14', (0, -1)),
          ('STF_15', (0, -1)),
          ('STF_16', (0, 1)),
          ('STF_17', (0, 1)),
          ('STF_18', (0, 1)),
          ('STF_19', (0, 1)),
          ('STF_20', (0, 1)),
          ('STF_21', (0, 1)),
          ('STF_22', (0, 1)),
          ('STF_23', (0, 1)),
          ('STF_24', (0, 1)),
          ('STF_25', (0, 1)),
          ('STF_26', (0, 1)),
          ('STF_27', (0, 1)),
          ('STF_28', (0, 1)),
          ('STF_29', (0, 1)),
          ('STF_30', (0, -1)),
          ('STF_31', (0, 1)),
          ('STF_32', (0, 1)),
          ('STF_33', (0, 1)),
          ('STF_34', (0, 1)),
          ('STF_35', (0, 1)),
          ('STF_36', (0, -1)),
          ('STF_37', (0, 1)),
          ('STF_38', (0, 1)),
          ('STF_39', (0, -1)))),
 'STZ': ('sequence',
         (('STZ_1', (0, 1)),
          ('STZ_2', (0, 1)),
          ('STZ_3', (0, 1)),
          ('STZ_4', (0, 1)))),
 'TCC': ('sequence',
         (('TCC_1', (1, 1)),
          ('TCC_2', (1, 1)),
          ('TCC_3', (0, 1)),
          ('TCC_4', (0, 1)),
          ('TCC_5', (0, 1)),
          ('TCC_6', (0, 1)),
          ('TCC_7', (0, 1)),
          ('TCC_8', (0, 1)),
          ('TCC_9', (0, 1)),
          ('TCC_10', (0, 1)),
          ('TCC_11', (0, 1)),
          ('TCC_12', (0, 1)),
          ('TCC_13', (0, 1)),
          ('TCC_14', (0, 1)))),
 'TCD': ('sequence',
         (('TCD_1', (1, 1)),
          ('TCD_2', (0, 1)),
          ('TCD_3', (0, 1)),
          ('TCD_4', (0, 1)),
          ('TCD_5', (0, 1)),
          ('TCD_6', (0, 1)),
          ('TCD_7', (0, 1)),
          ('TCD_8', (0, 1)))),
 'TQ1': ('sequence',
         (('TQ1_1', (0, 1)),
          ('TQ1_2', (0, 1)),
          ('TQ1_3', (0, -1)),
          ('TQ1_4', (0, -1)),
          ('TQ1_5', (0, -1)),
          ('TQ1_6', (0, 1)),
          ('TQ1_7', (0, 1)),
          ('TQ1_8', (0, 1)),
          ('TQ1_9', (0, -1)),
          ('TQ1_10', (0, 1)),
          ('TQ1_11', (0, 1)),
          ('TQ1_12', (0, 1)),
          ('TQ1_13', (0, 1)),
          ('TQ1_14', (0, 1)))),
 'TQ2': ('sequence',
         (('TQ2_1', (0, 1)),
          ('TQ2_2', (0, 1)),
          ('TQ2_3', (0, -1)),
          ('TQ2_4', (0, -1)),
          ('TQ2_5', (0, -1)),
          ('TQ2_6', (0, 1)),
          ('TQ2_7', (0, 1)),
          ('TQ2_8', (0, 1)),
          ('TQ2_9', (0, 1)),
          ('TQ2_10', (0, 1)))),
 'TXA': ('sequence',
         (('TXA_1', (1, 1)),
          ('TXA_2', (1, 1)),
          ('TXA_3', (0, 1)),
          ('TXA_4', (0, 1)),
          ('TXA_5', (0, -1)),
          ('TXA_6', (0, 1)),
          ('TXA_7', (0, 1)),
          ('TXA_8', (0, -1)),
          ('TXA_9', (0, -1)),
          ('TXA_10', (0, -1)),
          ('TXA_11', (0, -1)),
          ('TXA_12', (1, 1)),
          ('TXA_13', (0, 1)),
          ('TXA_14', (0, -1)),
          ('TXA_15', (0, 1)),
          ('TXA_16', (0, 1)),
          ('TXA_17', (1, 1)),
          ('TXA_18', (0, 1)),
          ('TXA_19', (0, 1)),
          ('TXA_20', (0, 1)),
          ('TXA_21', (0, 1)),
          ('TXA_22', (0, -1)),
          ('TXA_23', (0, -1)))),
 'UAC': ('sequence', (('UAC_1', (1, 1)), ('UAC_2', (1, 1)))),
 'UB1': ('sequence',
         (('UB1_1', (0, 1)),
          ('UB1_3', (0, 1)),
          ('UB1_4', (0, 1)),
          ('UB1_5', (0, 1)),
          ('UB1_6', (0, 1)),
          ('UB1_7', (0, 5)),
          ('UB1_8', (0, 1)),
          ('UB1_9', (0, 1)),
          ('UB1_10', (0, 8)),
          ('UB1_11', (0, 1)),
          ('UB1_12', (0, 1)),
          ('UB1_13', (0, 1)),
          ('UB1_14', (0, 1)),
          ('UB1_15', (0, 1)),
          ('UB1_16', (0, 5)),
          ('UB1_17', (0, 1)),
          ('UB1_18', (0, 1)),
          ('UB1_19', (0, 1)),
          ('UB1_20', (0, 1)),
          ('UB1_21', (0, 1)),
          ('UB1_22', (0, 1)),
          ('UB1_23', (0, 1)))),
 'UB2': ('sequence',
         (('UB2_1', (0, 1)),
          ('UB2_2', (0, 1)),
          ('UB2_3', (0, 7)),
          ('UB2_4', (0, 1)),
          ('UB2_5', (0, 1)),
          ('UB2_6', (0, 12)),
          ('UB2_7', (0, 8)),
          ('UB2_8', (0, 2)),
          ('UB2_9', (0, 2)),
          ('UB2_10', (0, 2)),
          ('UB2_11', (0, 1)),
          ('UB2_12', (0, 3)),
          ('UB2_13', (0, 23)),
          ('UB2_14', (0, 5)),
          ('UB2_15', (0, 1)),
          ('UB2_16', (0, 2)),
          ('UB2_17', (0, 1)))),
 'URD': ('sequence',
         (('URD_1', (0, 1)),
          ('URD_2', (0, 1)),
          ('URD_3', (1, -1)),
          ('URD_4', (0, -1)),
          ('URD_5', (0, -1)),
          ('URD_6', (0, -1)),
          ('URD_7', (0, 1)))),
 'URS': ('sequence',
         (('URS_1', (1, -1)),
          ('URS_2', (0, 1)),
          ('URS_3', (0, 1)),
          ('URS_4', (0, -1)),
          ('URS_5', (0, -1)),
          ('URS_6', (0, -1)),
          ('URS_7', (0, -1)),
          ('URS_8', (0, -1)),
          ('URS_9', (0, 1)))),
 'VAR': ('sequence',
         (('VAR_1', (1, 1)),
          ('VAR_2', (1, 1)),
          ('VAR_3', (0, 1)),
          ('VAR_4', (0, -1)),
          ('VAR_5', (0, 1)),
          ('VAR_6', (0, -1)))),
 'VND': ('sequence',
         (('VND_1', (1, 1)),
          ('VND_2', (1, 1)),
          ('VND_3', (0, 1)),
          ('VND_4', (0, 1)),
          ('VND_5', (0, 1))))}
